package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See F<LICENSE>.

=cut

$^V eq 5.34.0 
    or die sprintf("Perl (%s) version (%vd) doesn't match the version (5.34.0) ".
                   "that PAR::Packer was built with; please rebuild PAR::Packer", 
                   $^X, $^V);

1;

__DATA__
M?T5,1@(!`0````````````,`/@`!````T"4```````!``````````#C!````
M`````````$``.``-`$``'``;``8````$````0`````````!``````````$``
M````````V`(```````#8`@````````@``````````P````0````8`P``````
M`!@#````````&`,````````<`````````!P``````````0`````````!````
M!````````````````````````````````````"`:````````(!H`````````
M$`````````$````%`````"``````````(``````````@````````<CX`````
M``!R/@`````````0`````````0````0`````8`````````!@`````````&``
M```````81P```````!A'`````````!`````````!````!@````"P````````
M`+``````````L````````"`0````````H"``````````$`````````(````&
M````(+`````````@L````````""P````````T`$```````#0`0````````@`
M````````!`````0````X`P```````#@#````````.`,````````@````````
M`"``````````"``````````$````!````%@#````````6`,```````!8`P``
M`````$0`````````1``````````$`````````%/E=&0$````.`,````````X
M`P```````#@#````````(``````````@``````````@`````````4.5T9`0`
M``!PGP```````'"?````````<)\```````#\`````````/P`````````!```
M``````!1Y71D!@``````````````````````````````````````````````
M```````````0`````````%+E=&0$`````+``````````L`````````"P````
M`````!``````````$`````````$`````````+VQI8C8T+VQD+6QI;G5X+7@X
M-BTV-"YS;RXR```````$````$`````4```!'3E4``H``P`0````!````````
M``0````4`````P```$=.50#)*)]`CJV$_U#BNQ\>4&(E60BV>00````0````
M`0```$=.50```````P````(``````````````!$````_````!`````@````@
M'!``!4`$AB@"0`20A@"$@@D`($D@!`BXHA%%N@`""@`````_````0@```$4`
M``!&````30```$X```!0````5````%4```!7````6````%L```!=````7P``
M````````````;L7?'\[>1RUK?YI\+L6;MB#_Y`[59-1\V7%8'.)'Q@%"^M>'
MK$OCP+KCDGS"Y3\L^J%L8+,!BV]K"4/69J_,9L6YG$!"1=7LQ(D%D(@'<-,Y
M\HL<#13BGMK-XYXS8MOM%8PES`PZEPM6I)N6I]VC:WZIG)O19<YMX*<""FL:
MGE`*BA!7H^#[20````````````````````````````````````#A````$@``
M``````````````````````"*`0``$@````````````````````````#D`0``
M$@````````````````````````#"`0``$@`````````````````````````!
M````(`````````````````````````#K`0``$@``````````````````````
M``!J`@``$@```````````````````````````@``$@``````````````````
M``````!%`0``$@`````````````````````````^`@``$@``````````````
M``````````!4`@``$@````````````````````````!T````$@``````````
M``````````````!"`P``$@````````````````````````#<````$@``````
M```````````````````C`@``$@`````````````````````````5`@``$@``
M``````````````````````#3`0``$@````````````````````````!C`@``
M$@`````````````````````````_`@``$@````````````````````````!S
M`@``$@`````````````````````````W`0``$@``````````````````````
M```%`0``$@````````````````````````!S`0``$@``````````````````
M``````"W`0``$@````````````````````````#*`0``$@``````````````
M``````````#3`@``$@````````````````````````!@`0``$@``````````
M``````````````#Y`0``$@````````````````````````"%`0``$@``````
M``````````````````"W`@``$@````````````````````````"P`@``$@``
M```````````````````````3`0``$@`````````````````````````=````
M(``````````````````````````W`@``$@````````````````````````!4
M````$@````````````````````````"C`0``$@``````````````````````
M``!L`0``$@````````````````````````"#````$@``````````````````
M``````"/````$@`````````````````````````L`0``$@``````````````
M``````````#R````$@````````````````````````!&````$@``````````
M``````````````#F````$@````````````````````````!&`@``$@``````
M``````````````````!5`0``$@````````````````````````#`````$@``
M``````````````````````#Q`0``$@````````````````````````!^`0``
M$@````````````````````````"A`@``$@````````````````````````!Z
M`@``$@````````````````````````!C````$@``````````````````````
M``"I`@``$@`````````````````````````.`@``$@``````````````````
M``````"D````$@`````````````````````````C`0``$@``````````````
M``````````"]`0``$@````````````````````````";`0``$@``````````
M```````````````I`@``$@`````````````````````````L````(```````
M```````````````````'`@``$@`````````````````````````<`@``$@``
M``````````````````````"3`@``$@````````````````````````!+`P``
M$@`/`'!"````````!@$```````!W`P``$@`/`.`W````````[`<```````#$
M`@``$@`/`,`C````````!P(````````?`P``$@`/`&`N````````!0``````
M```+!```$@`/`'`N`````````@(```````!!!```$@`/`-`_````````G0(`
M``````#W`P``$``9`"#```````````````````!>`P``$@`/`(`P````````
M)0````````"$`P``$@`/`!!:````````GP$```````"<`P``$0`1``!@````
M````!`````````#;`P``$``9`*#0```````````````````#!```$@`/`'`M
M````````,``````````8!```$@`/`-`V````````"P$````````J!```$@`/
M`#`V````````=`````````"/`P``$``8``#```````````````````!K`P``
M$@`/`+`P````````W`````````#)`@``$0`9`$#`````````"`````````!7
M`P``$``8`"#```````````````````#*`@``(0`9`$#`````````"```````
M``#1`P``$0`8`!C`````````"`````````!<`@``$0`9`&#`````````"```
M```````/`P``$@`/``!>`````````0````````#!`P``$@`/`*!=````````
M70````````"5`P``$@`/`-`E````````*P`````````X!```$@`/`+!9````
M````5`````````"1`P``(``8``#```````````````````#1````$0`9`"#`
M````````!`````````#+`@``(0`9`$#`````````"``````````P`P``$@`/
M`+`V````````'0````````"$`@``(@````````````````````````"K`P``
M$@`/`*`M````````OP````````#M`P``$@`/`+!;````````ZP$```````"S
M````$0`9`##``````````0````````#@`P``$@`/`)`Q````````G@0`````
M````7TE435]D97)E9VES=&5R5$U#;&]N951A8FQE`%]?9VUO;E]S=&%R=%]?
M`%])5$U?<F5G:7-T97)434-L;VYE5&%B;&4`4&5R;%]S>7-?=&5R;0!097)L
M7W-Y<U]I;FET,P!097)L7V%T9F]R:U]L;V-K`'!E<FQ?8V]N<W1R=6-T`%!E
M<FQ?9V5T7W-V`%!E<FQ?8W)O86M?;F]C;VYT97AT`%!E<FQ?<W9?<V5T<'9N
M`%!,7V1O7W5N9'5M<`!097)L7VYE=UA37V9L86=S`%!,7W1H<E]K97D`<&5R
M;%]F<F5E`%!E<FQ?;6=?<V5T`%!E<FQ?871F;W)K7W5N;&]C:P!097)L7W-V
M7W-E='!V`%!E<FQ?9W9?9F5T8VAP=@!P97)L7W)U;@!097)L7VYE=UA3`'!E
M<FQ?9&5S=')U8W0`8F]O=%]$>6YA3&]A9&5R`'!E<FQ?<&%R<V4`4&5R;%]S
M869E<WES;6%L;&]C`'!E<FQ?86QL;V,`;W!E;C8T`')E860`7U]E<G)N;U]L
M;V-A=&EO;@!L<V5E:S8T`'!T:')E861?9V5T<W!E8VEF:6,`8VQO<V4`97AI
M=`!S=')N8VUP`&-L;W-E9&ER`%]?<W1A8VM?8VAK7V9A:6P`=6YL:6YK`&UK
M9&ER`')E86QL;V,`;65M8VAR`&=E='!I9`!S=')D=7``<W1R=&]K`'-T<FQE
M;@!S=')S='(`<FUD:7(`7U]F<')I;G1F7V-H:P!M96UC<'D`;'-T870V-`!?
M7W-T<FYC<'E?8VAK`&]P96YD:7(`<W1D97)R`&=E='5I9`!R96%D;&EN:P!S
M=')C:'(`<F5A9&1I<C8T`%]?8WAA7V9I;F%L:7IE`%]?<W!R:6YT9E]C:&L`
M;65M;6]V90!A8V-E<W,`<W1R8VUP`%]?;&EB8U]S=&%R=%]M86EN`%]?96YV
M:7)O;@!?7W)E9VES=&5R7V%T9F]R:P!L:6)P97)L+G-O+C4N,S0`;&EB<'1H
M<F5A9"YS;RXP`&QI8F,N<V\N-@!?7VQI8F-?8W-U7V9I;FD`<&%R7V-U<G)E
M;G1?97AE8P!G971?=7-E<FYA;65?9G)O;5]G971P=W5I9`!P87)?8VQE86YU
M<`!?961A=&$`<&%R7V)A<V5N86UE`'!A<E]D:7)N86UE`'!A<E]M:W1M<&1I
M<@!S:&%?=7!D871E`%]?9&%T85]S=&%R=`!?24]?<W1D:6Y?=7-E9`!P87)?
M8W5R<F5N=%]E>&5C7W!R;V,`7U]L:6)C7V-S=5]I;FET`&UY7W!A<E]P;`!?
M96YD`'!A<E]I;FET7V5N=@!S:&%?9FEN86P`7U]B<W-?<W1A<G0`>'-?:6YI
M=`!P87)?9FEN9'!R;V<`<&%R7W-E='5P7VQI8G!A=&@`<&%R7V5N=E]C;&5A
M;@!S:&%?:6YI=`!84U]);G1E<FYA;'-?4$%27T)/3U0`1TQ)0D-?,BXR+C4`
M1TQ)0D-?,BXS+C0`1TQ)0D-?,BXQ-`!'3$E"0U\R+C,N,@!'3$E"0U\R+C0`
M1TQ)0D-?,BXS,P`````"``,``@`"``$``@`"``(``0`$``(``0`"``$``@`"
M``4``@`$``(``0`!``$``P`"``8``0`"``,``@`"``$``0`'``$``P`"``$`
M`0`!``$``0`!``@``0`!``(``P`"``(``0`"``(``0`!``(``P`(``$``@`"
M``@``0`!``$``0`!``$``0`!``$``0`!``$``0`!``$``0`"``$``@`!``(`
M`0`!``$``0`!``$``@`!``(``0`!``$``0````$``0#U`@``$````"````!U
M&FD)```#`%<$`````````0`&``4#```0`````````'09:0D```@`8P0``!``
M``"4D98&```'`&\$```0````<AEI"0``!@!Z!```$````!1I:0T```4`A@0`
M`!````"SD98&```$`)`$```0````=1II"0```@!7!`````````C`````````
M"``````````(P````````!C`````````"`````````#@8@```````,"S````
M````!@````4``````````````,BS````````!@````D``````````````-"S
M````````!@```!X``````````````-BS````````!@```"$`````````````
M`."S````````!@```"D``````````````.BS````````!@```#,`````````
M`````/"S````````!@```#L``````````````/BS````````!@```%P`````
M`````````"#`````````!0```%D``````````````##`````````!0```%\`
M`````````````$#`````````!0```$\``````````````&#`````````!0``
M`%,```````````````BR````````!P````$``````````````!"R````````
M!P````(``````````````!BR````````!P````,``````````````""R````
M````!P````0``````````````"BR````````!P````8``````````````#"R
M````````!P````<``````````````#BR````````!P````@`````````````
M`$"R````````!P````H``````````````$BR````````!P````L`````````
M`````%"R````````!P````P``````````````%BR````````!P````T`````
M`````````&"R````````!P````X``````````````&BR````````!P````\`
M`````````````'"R````````!P```!```````````````'BR````````!P``
M`!$``````````````("R````````!P```!(``````````````(BR````````
M!P```!,``````````````)"R````````!P```!0``````````````)BR````
M````!P```!4``````````````*"R````````!P```!8``````````````*BR
M````````!P```!<``````````````+"R````````!P```!@`````````````
M`+BR````````!P```!D``````````````,"R````````!P```!H`````````
M`````,BR````````!P```!L``````````````-"R````````!P```!P`````
M`````````-BR````````!P```!T``````````````."R````````!P```!\`
M`````````````.BR````````!P```"```````````````/"R````````!P``
M`"(``````````````/BR````````!P```",```````````````"S````````
M!P```"0```````````````BS````````!P```"4``````````````!"S````
M````!P```"8``````````````!BS````````!P```"<``````````````""S
M````````!P```"@``````````````"BS````````!P```"H`````````````
M`#"S````````!P```"L``````````````#BS````````!P```"P`````````
M`````$"S````````!P```"T``````````````$BS````````!P```"X`````
M`````````%"S````````!P```"\``````````````%BS````````!P```#``
M`````````````&"S````````!P```#$``````````````&BS````````!P``
M`#(``````````````'"S````````!P```#0``````````````'BS````````
M!P```#4``````````````("S````````!P```#8``````````````(BS````
M````!P```#<``````````````)"S````````!P```#@``````````````)BS
M````````!P```#D``````````````*"S````````!P```#H`````````````
M`*BS````````!P```#P``````````````+"S````````!P```#T`````````
M`````+BS````````!P```#X`````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``!(@^P(2(L%S9,``$B%P'0"_]#HZ08``.@$/@``2(/$",,`````````````
M``````#_-<*1``#_)<21```/'T``_R7"D0``:`````#IX/____\ENI$``&@!
M````Z=#_____);*1``!H`@```.G`_____R6JD0``:`,```#IL/____\EHI$`
M`&@$````Z:#_____)9J1``!H!0```.F0_____R62D0``:`8```#I@/____\E
MBI$``&@'````Z7#_____)8*1``!H"````.E@_____R5ZD0``:`D```#I4/__
M__\E<I$``&@*````Z4#_____)6J1``!H"P```.DP_____R5BD0``:`P```#I
M(/____\E6I$``&@-````Z1#_____)5*1``!H#@```.D`_____R5*D0``:`\`
M``#I\/[___\E0I$``&@0````Z>#^____)3J1``!H$0```.G0_O___R4RD0``
M:!(```#IP/[___\E*I$``&@3````Z;#^____)2*1``!H%````.F@_O___R4:
MD0``:!4```#ID/[___\E$I$``&@6````Z8#^____)0J1``!H%P```.EP_O__
M_R4"D0``:!@```#I8/[___\E^I```&@9````Z5#^____)?*0``!H&@```.E`
M_O___R7JD```:!L```#I,/[___\EXI```&@<````Z2#^____)=J0``!H'0``
M`.D0_O___R72D```:!X```#I`/[___\ERI```&@?````Z?#]____)<*0``!H
M(````.G@_?___R6ZD```:"$```#IT/W___\ELI```&@B````Z<#]____):J0
M``!H(P```.FP_?___R6BD```:"0```#IH/W___\EFI```&@E````Z9#]____
M)9*0``!H)@```.F`_?___R6*D```:"<```#I</W___\E@I```&@H````Z6#]
M____)7J0``!H*0```.E0_?___R5RD```:"H```#I0/W___\E:I```&@K````
MZ3#]____)6*0``!H+````.D@_?___R5:D```:"T```#I$/W___\E4I```&@N
M````Z0#]____)4J0``!H+P```.GP_/___R5"D```:#````#IX/S___\E.I``
M`&@Q````Z=#\____)3*0``!H,@```.G`_/___R4JD```:#,```#IL/S___\E
M(I```&@T````Z:#\____)1J0``!H-0```.F0_/___R42D```:#8```#I@/S_
M__\E0I```&:0``````````!!5%5(@^PXB7PD'$B-?"0<2(ET)!!(C70D$$B)
M5"0(2(U4)`AD2(L$)2@```!(B40D*#'`Z"?^__](BS7@CP``2(L]X8\``$B)
M\N@!.@``@#T:G````'4OZ&/]__](B05TK```2(G'2(7`#X2(`0``Z)O\__^+
M/>6;``#H\/W__\:`UPD```"+/=.;``#HWOW__XL]R)L``("(*@0```+HS/W_
M_X"(*@0```&+1"0<C7@$1(U@`TAC_TC!YP/H/OW__TB+?"002(G!2(D%_ZL`
M`$B+!TB)`4B-!3`]``!(B4$(2(L%;YL``$B)01!(C04=/0``2(E!&(M$)!R#
M^`$/CND```!(@\<(@\`#N@0````/'X``````3(L'2&/R@\(!2(/'"$R)!/$Y
MT'7K2)A(BSVBJP``1(GB13'`2,<$P0````!(C37U!P``Z*#]__]!B<2%P'13
M2(L]>JL``$B-;"0DZ#C\__\QP$B)[DB-/6\[``#HUP$``$B%P'0]2(L]4ZL`
M`.BF^___Z#']__](BT0D*&1(*P0E*````'5C2(/$.$2)X%U!7,-(BSTGJP``
MZ,K]__]!B<3KG$B+/0:K``!(A?]T!^CD'```Z[!(C3W#.@``2(GNZ',!``!(
MB07DJ@``2(G'2(7`=)+KV;@$````Z37___^_`0```.B._?__Z%G[__]F#Q^$
M```````Q[4F)T5Y(B>)(@^3P4%1,C04:.```2(T-LS<``$B-/<S]____%=:-
M``#T#Q]$``!(C3T9F@``2(T%$IH``$@Y^'052(L%IHT``$B%P'0)_^`/'X``
M````PP\?@`````!(C3WIF0``2(TUXID``$@I_DB)\$C![C](P?@#2`'&2-'^
M=!1(BP65C0``2(7`=`C_X&8/'T0``,,/'X``````\P\>^H`][9D```!U>U5(
M@SURC0```$B)Y4%44W0,2(L]<YD``.@6_?__2(T%;XD``$B-'7")``!(*<-)
MB<1(BP6[F0``2,'[`TB#ZP%(.=AS(68/'T0``$B#P`%(B06=F0``0?\4Q$B+
M!9*9``!(.=ARY>@8____6T%<Q@5VF0```5W##Q]``,,/'X``````\P\>^NDG
M____#Q^``````$%7059!54%455-(@^P(2(7_#X2Q````3(LM$ID``$V%[0^$
MH0````^V!TF)_TB)]83`=`0\/75813'V38ME`$V%Y'0R36/V3(GK9@\?1```
M3(GR3(G^3(GGZ`+Y__^%P'4'0X`\-#UT1TR+8PA(@\,(387D==I(@\0(3(G@
M6UU!7$%=05Y!7\,/'X0``````$F)_D$/MD8!28/&`83`=`0\/77O12G^ZY(/
M'X``````3"GK3XUD-`%(P?L#B5T`Z[4/'X``````13'DZZD/'P!!5D%50515
M4TB![*````!D2(L$)2@```!(B80DF````#'`2(7_=`B`/P!(B?UU,4B+A"28
M````9$@K!"4H````#X4A`0``2('$H````%M=05Q!74%>PV8N#Q^$``````#H
M>_C__TR-+;@W``!)B<1(A<!TNTR)Y^BD^O__2(7`#X2C````@'@3+DB-6!-U
M"8![`0!TWP\?`(!X$RX/A)X```!(B>_HAOC__TB)WTF)QNA[^/__08U\!@)(
M8__HGOG__TF)V4F)Z$R)Z4F)QDB)Q[X!````,<!(Q\+_____Z-SZ__],B?=(
MB>;H<?C__TR)]X/X_W00BT0D&"4`\```/0!```!T6>AT]___3(GWZ$SW__],
MB>?H!/K__TB%P`^%8/___P\?`$R)Y^B0^/__2(GOZ.CW___I\O[__P\?`(![
M`2X/A5C___^`>P(`#X0@____Z4G___\/'X``````Z)O^___KI>C4]___#Q]`
M`%5(B?U(@>R@````9$B+!"4H````2(F$))@````QP$B)YN@Z]___A<!U-HM4
M)!B!X@#P``"!^@!```!T"('Z`*```'4>O@(```!(B>_H;_G__X7`#Y3`#[;`
MZP</'T0``#'`2(N4))@```!D2"L4)2@```!U"4B!Q*````!=P^A-]___9F8N
M#Q^$``````!FD$%6NO\/``!!54%428GT54B)_4B-/1$V``!(@>P8$```9$B+
M!"4H````2(F$)`@0```QP$F)Y4R)[NAR]O__A<!^3HU0_TQC\D*`/#0`#X5]
M````A=)T.4R)\KXO````3(GOZ(GW__](A<!T)(L]SI4``.C9]___3(GQ3(GJ
M2(GN2(G'Z,CX___K'V8/'T0``(L]JI4``.BU]___3(GB2(GN2(G'Z.?V__](
MBX0D"!```&1(*P0E*````'4<2('$&!```%U!7$%=05[##Q]$``!,8_#I?___
M_^AC]O__#Q\`05=!5D%505152(GU4TB)^TB#[!AD2(L$)2@```!(B40D"#'`
M,<"`/CT/E,!(`<5(B>_H&?;__TB-="0$2(G?28G$,<#H!_S__TB%P`^$!@$`
M`$B)QTF)Q>CS]?__23G$#X;2````3&-T)`1)P>8##[8#A,`/A)X!```\/0^$
ME@$``$B)V`\?``^V4`%(@\`!A-)T!8#Z/77O2"G82)A,BRW;E```2HU\(`+H
MT?;__TT!]4F)10!(A<!T5DB+!;Z4``!(C4L!2HL4,`^V`X@"A,!T(CP]=0WK
M'`\?@`````"$P'01#[8!2(/"`4B#P0&(`CP]=>O&`CTQP&8/'T0```^V3`4`
MB$P"`4B#P`&$R77O2(M$)`AD2"L$)2@````/A0<!``!(@\086UU!7$%=05Y!
M7\,/'T``,<!F#Q]$```/ME0%`$&(5`4`2(/``832=>[KO0\?0`!,BSTAE```
M28,_``^$M@```$R)^$4Q[9!(@\`(1(GJ08/%`4B#.`!U[XUR`TAC]DC!Y@.+
M!2^D``"%P'5;QP4AI````0```$B)]^C9]?__2(7`#X1A____36/U3(G^2(G'
M2<'F`TR)\NAK]O__2(D%M),``$B)P4&-10%$B6PD!$B82,<$P0````#IB/[_
M_V8/'X0``````$R)_^@8]O__2(D%@9,``$B)P4B%P`^$!O___TUC]4G!Y@/K
MNP\?0``QP.E__O__OA````!%,>WI7____^@O]/__9F8N#Q^$```````/'T``
M2(/L"(L]%I,``.@A]?__BST+DP``Z!;U__](BQ6GA@``2(T-$'(``$B-->HR
M``!(B<?H.?7__XL]XY(``.CN]/__3(T%8C0``$4QR4B-%7T2``!(B<=,B<%(
MC375,@``2(/$".E7]?__#Q^``````$B#[`B+/::2``#HL?3__TB+%4*&``!(
M@\0(2(T-IW$``$B)QTB--7XR``#IT/3__T%455-(@>P@(```9$B+!"4H````
M2(F$)!@@```QP$B)Y4R-I"00$```Z-+R__],C0U`,@``N@$0``!(B>]!B<!(
MC0UC,@``O@$````QP.BM]?__N@`0``!,B>9(B>_HC?+__T4QP(7`>"Z->`%(
MB<-(8__H*/3__TF)P$B%P'082&/;3(GF2(G'2(G:Z-_S___&!!@`28G`2(N$
M)!@@``!D2"L$)2@```!U#TB!Q"`@``!,B<!;74%<P^C!\O__D.D[____9F8N
M#Q^$``````!!5T%6055!5$F)]%5(B?U(C3W2,0``4TB![,@0``!D2(L$)2@`
M``!(B80DN!```#'`2(UT)!SH9?C__[XO````2(GO2(G#Z)7R__](A<!T0#'`
M2(GN2(T]E3$``.CO^___2(GH2(N4)+@0``!D2"L4)2@````/A8(!``!(@<3(
M$```6UU!7$%=05Y!7\,/'P!(B>_H"/+__TR)YTR-)5PQ``!!B<;H9O3__TR)
MYDB)Q^C[\___28G%2(7`=)-!C48!08!]``!,C34I,@``B40D#`^$Q@```&8/
M'X0``````$B%VW033(GN2(G?Z)#R__^%P`^$A````$R)[^B@\?__ZPEF#Q]$
M``#&`@")P8/H`4ACT$P!ZH`Z+W3M`TPD#('Y_P\```^/)?___TR-O"2P````
M3(GQ38GH,<!(@^P(N@`0``"^`0```$R)_U5,C0VL,```Z-?S__](C70D,$R)
M_^AJ\?__6EF%P'40BT0D."4`\```/0"```!T5$R)YC'_Z"KS__])B<5(A<`/
MA+[^__]!@'T```^%0____TB%VW0%@#LN=!E,C2TX,```N0$```#I8____P\?
MA```````@'L!`'2VZ]\/'X0``````+X!````3(G_Z,/R__^%P'6;3(G^2(T]
M!C```.A@^O__3(G_Z!CS___I9_[__^BN\/__9F8N#Q^$```````/'P`/M@=)
MB?B$P'079@\?1```2(/'`3PO#[8'3`]$QX3`=>],B<##9F8N#Q^$``````!(
MA?\/A,<```!5@#\`2(G]#X2B````Z$7P__](C50%_T@YU7(4Z9L```!F#Q]$
M``!(@^H!2#G5="6`.B]T\D@YU0^#?@```$B#Z@%(.=5T#H`Z+W0H2(/J`4@Y
MU77R@'T`+W142(T]52\``%WI7_+__P\?@`````"`.B]U"4B#Z@%(.=5R\D@I
MZC'`2(U*`DB!^0`0``!W&$B#P@&Y`!```$B)[DB-/26/``#H0/'__UW#9@\?
M1```2(T]YRX``%WI"_+__T@YU76SZY(/'T``2(T]SRX``.GT\?__#Q]``$%7
M059!54%455-(C1W1+@``2(/L2&8/;P6C;0``9$B+!"4H````2(E$)#@QP#'`
M2(UL)`P/*40D$&8/;P6/;0``9HE$)#`/*40D(`\?1```,<!(B>Y(B=_H(_7_
M_TB%P'0V2&-4)`Q(BP5"C@``2(T$T$B+4`A(B1!(A=)TTF:02(M0$$B#P`A(
MB1!(A=)U\.N^9@\?1```2(T=3"X``)`QP$B)[DB)W^C3]/__2(7`=#9(8U0D
M#$B+!?*-``!(C0302(M0"$B)$$B%TG329I!(BU`02(/`"$B)$$B%TG7PZ[YF
M#Q]$``!(C1T$+@``D#'`2(GN2(G?Z(/T__](A<!T-DAC5"0,2(L%HHT``$B-
M!-!(BU`(2(D02(72=-)FD$B+4!!(@\`(2(D02(72=?#KOF8/'T0``$B-';TM
M``"0,<!(B>Y(B=_H,_3__TB%P'0V2&-4)`Q(BP52C0``2(T$T$B+4`A(B1!(
MA=)TTF:02(M0$$B#P`A(B1!(A=)U\.N^9@\?1```3(TE="T``)`QP$B)[DR)
MY^CC\___2(7`=#9(8U0D#$B+!0*-``!(C0302(M0"$B)$$B%TG329I!(BU`0
M2(/`"$B)$$B%TG7PZ[YF#Q]$``!(C1TT+0``D#'`2(GN2(G?Z)/S__](A<!T
M-DAC5"0,2(L%LHP``$B-!-!(BU`(2(D02(72=-)FD$B+4!!(@\`(2(D02(72
M=?#KOF8/'T0``$R-+9DL``"0,<!(B>Y,B>_H0_/__TB%P'0V2&-4)`Q(BP5B
MC```2(T$T$B+4`A(B1!(A=)TTF:02(M0$$B#P`A(B1!(A=)U\.N^9@\?1```
M3(T]H"P``)`QP$B)[DR)_^CS\O__2(7`=#9(8U0D#$B+!1*,``!(C0302(M0
M"$B)$$B%TG329I!(BU`02(/`"$B)$$B%TG7PZ[YF#Q]$``!,C35:+```D#'`
M2(GN3(GWZ*/R__](A<!T-DAC5"0,2(L%PHL``$B-!-!(BU`(2(D02(72=-)F
MD$B+4!!(@\`(2(D02(72=?#KOF8/'T0``$B-'10L``"0,<!(B>Y(B=_H4_+_
M_TB%P'0V2&-4)`Q(BP5RBP``2(T$T$B+4`A(B1!(A=)TTF:02(M0$$B#P`A(
MB1!(A=)U\.N^9@\?1```2(T=8BL``)`QP$B)[DB)W^@#\O__2(7`=#9(8U0D
M#$B+!2*+``!(C0302(M0"$B)$$B%TG329I!(BU`02(/`"$B)$$B%TG7PZ[YF
M#Q]$``!(B>Y(C3U[*P``Z+GQ__](B<9(A<!T"DR)]S'`Z%?U__](B>Y(C3UK
M*P``,<#HEO'__TB)QDB%P'0.2(T]9RL``#'`Z##U__](B>Y(C3UA*P``,<#H
M;_'__TB)QDB%P'0Z3(GO,<#H#?7__S'`2(TU:RL``$R)Y^C\]/__2(M$)#AD
M2"L$)2@```!U54B#Q$A;74%<05U!7D%?PTB)[DB-/1XK```QP.@<\?__2(G&
M2(7`=`Q,B?\QP.BZ]/__ZZM(N%!!4E]#3$5!2#E$)"%UFF:!?"0I3CUUD4B-
M="0KZ]/H\NK__V:02(/L&&1(BP0E*````$B)1"0(BP7(B0``@_C_=!M(BU0D
M"&1(*Q0E*````'5"2(/$&,-F#Q]$``!(C70D!$B-/3LJ```QP.B5\/__2(G"
M,<!(A=)T$@^V`CPP#Y7"A,`/E<`/ML`AT(D%<XD``.NNZ'SJ__]F9BX/'X0`
M`````)!(@^P(Z'?J__^)Q^@@ZO__2(7`=`-(BP!(@\0(PP\?`$%5051,C25.
M*@``54B)_4R)YU-(@^P89$B+!"4H````2(E$)`@QP$B-="0$Z`_P__](A<!T
M"(`X`$B)PW4R2(M$)`AD2"L$)2@````/A;0```!(B>Y(@\083(GG,<!;74%<
M05WIA_/__P\?@`````!(B>Y(B<?H1>S__TB%P'0@2(M$)`AD2"L$)2@```!U
M=DB#Q!A;74%<05W##Q]$``!(B>_HF.G__TB)WTF)Q>B-Z?__28U\!0+HL^K_
M_TB#[`A)B>B^`0```%-(Q\+_____2(G'28G%3(T-P"@``$B-#;$I```QP.CD
MZ___6%I(BT0D"&1(*P0E*````'4(3(GNZ4_____H1>G__P\?1```05=!5DR-
M-6TH``!!54%455-(@>R(@0``2(D\)$B-;"0<3(GW2(GN9$B+!"4H````2(F$
M)'B!``!(C04W*```2,=$)#``````2,>$)(@`````````2,=$)%``````2(E$
M)"A(C06@*```2(E$)&A(C07U*```2(E$)'!(C06E*```2(E$)'A(C07E*```
M2(F$)(````!(C07:*```2(E$)$@QP.B([O__2(7`=`R`.`!)B<0/A9<$``#H
MDNC__XG'Z#OH__](A<`/A-H#``!,BRA-A>T/A,X#``!,B>_H3NC__TB-?``!
MZ'3I__]%#[9%`$F)Q$6$P'0^38GG2(T=?"@```\?1```10^VP$R)_TB)V;X!
M````2,?"_____S'`28/%`4F#QP+HD^K__T4/MD4`183`==%(C5PD8$B-/<TG
M``#K%`\?`$B+>PA(@\,(2(7_#X0O`0``2(GN,<#HS>W__TF)Q4B%P'3=@#@`
M=-A(B<?H^.___X7`=,Q,B>_H'.K__TF)P$B%P`^$^````$R)QTR)1"0(Z)/G
M__],B>=(B</HB.?__T2-O`,$!```36/_3(G_Z*7H__]!5$R-#<PF``!(C0VY
M)P``28G%2(T%N"<``$C'PO____^^`0```%!,BT0D&$R)[S'`Z,_I__],B>^^
MP`$``.BBYO__7T%8@_C_=1+H9>;__T2+"$&#^1$/A00#``!(C;0DD````$R)
M[^BHYO__B<.%P`^$O@```$B+!"1-B>B^`0```$4QY$B+/3B&``!(C17I)P``
M2(L(,<#H-^G__TB+A"1X@0``9$@K!"4H````#X5W!0``2('$B($``$R)X%M=
M05Q!74%>05_##Q\`,=M,C2W4)@``ZQD/'T0``$ACPTR+;,0@387M=#M!@'T`
M`'0T3(GO@\,!Z+GN__^%P'3=3(GOZ-WH__])B<!(A<`/A<'^__](8\-,BVS$
M($V%[77)#Q]``$4QP.FH_O__#Q^$``````"+A"2H````)0#P```]`$````^%
M*____T2+I"2L````Z#SF__]!.<0/A17___^+A"2H````)?\!```]P`$```^%
M_O[__TR)_^@DY___2(GN2(T]#B8``$F)Q#'`Z.#K__](B<9(A<`/A#0"``!(
MBP0D2(LXZ"CS__])B<=(A<`/A!P"``!,B?_HM.7__TB)PH/X`WX\2)A(C34%
M)@``2(E4)`A)C7P'_.ATYO__A<!U($B+5"0(@_H$#X2&`P``C4+[2)A!@#P'
M+P^$=@,``&:0BP5JA```@_C_#X0A`P``2(T]^20``(7`#X3(`0``2(TU8B4`
M`#'`2(TMW24``.CM[O__3(T]OR4``.C!Y/__54C'PO____]-B>A03(T-?B0`
M`+X!````3(GG2(T-BB4``#'`Z)CG__]86NM$#Q]``.@[Y/__@S@1=4CH@>3_
M_X/#`4B#[`A-B>A53(T-/R0``$R)^;X!````4TC'PO____],B>=0,<#H5.?_
M_TB#Q""^P`$``$R)Y^@CY/__@_C_=*Y,B>_HUN/__TR)]TR)YC'`Z$GN__],
MB>?H4?K__^FU_?__#Q]``#';2(T]J"0``.L2#Q]$``!(8\-(BWS$0$B%_W0X
M2(GN,<"#PP'H7NK__TB%P'3A@#@`=-Q(B<?HO.;__TF)Q4B%P`^%ZOO__TAC
MPTB+?,1`2(7_=<B_#0```$R-+54D``#H4N7__T&X4P```$F)Q.G=^___2(L$
M)$V)Z+X!````13'D2(L]3H,``$B-%;\D``!(BP@QP.A-YO__Z1']__\/'X0`
M`````$B)Q^B8^?__2(N$)'B!``!D2"L$)2@````/A7@"``!(@<2(@0``3(GG
M6UU!7$%=05Y!7^D8YO__#Q^$``````!(BP0D3(LXZ=C]___'!8J"````````
M3(G_,?8QP.A.Y?__2(T]%B,``(G%A<`/A!O^__^Z`@```$C'QN[___^)Q^BJ
MY?__2(V<)'`!``"Z!@```(GO2(G>Z!/D__^`O"1P`0```'4.@+PD<0$``$,/
MA'H!```QTC'VB>_H<.7__S'`Z+D;``!)B<?K#P\?0`!(B=Y,B?_H!1P``+H`
M@```2(G>B>_HQN/__XG"A<!_X(GO2(VL)"`!``!(C1TN(P``Z%KC__],B?Y(
MB>_H;QT``$B-A"1``0``2(E$)`A)B<=(C80D:`$``$B)!"0/'P!$#[9%`$R)
M_TB)V;X!````2,?"_____S'`2(/%`4F#QP+H&N7__TPY/"1UU$B-!1@C``#&
MA"1H`0```%#_="002(T-U2(``$V)Z$R)YS'`O@$```!,C0VU(0``2,?"____
M_^C9Y/__65[IE/W__V:02(T]V"$``#'`2(GN2(D\).@KZ/__2(7`#X2._O__
M#[8`A,`/A(/^__\\,`^$>_[__\<%!8$```$```!(BSPDZ:K\__](BP0D2(M0
M"$B%T@^$>_S__TB)UTB)%"3HW^'__TB#^`,/AF7\__](BQ0D2(TU,2(``$B-
M?`+\Z*#B__](BQ0DA<!,#T3ZZ4'\__^`O"1R`0``00^%>/[__X"\)',!``!#
M#X5J_O__@+PD=`$``$@/A5S^__^`O"1U`0``10^%3O[__[H"````2,?&QO__
M_XGOZ+;C__^Z*0```$B)WHGOZ"?B__](C07K(0``4%/IV?[__^A4X?__#Q]`
M`$%505152(/L$(L]08```&1(BP0E*````$B)1"0(,<#H/.+__XL])H```$B)
MQ>@NXO__#[:5L````$B-;"0$2(T]?B```$B)[HB0L0```#'`Z.OF__](A<!T
M"8`X,0^$M0$``#'`Z%;Q__^+/>!_``#HZ^'__[D#````N@$```!(C354(0``
M2(G'Z*+A__])B<1(A<!T.$B+0!"+/;!_``!,BRCHN.'__TB-%2TA``!(B<=,
MB>[HYN#__TF+1"003(L@0?9$)`Y`#X62`0``BSU\?P``Z(?A__^Y`P```+H!
M````2(TU]R```$B)Q^@^X?__28G$2(7`=#Y(C3V0'P``2(GN,<#H->;__XL]
M/W\``$F)Q4B%P`^$$P$``$F+1"003(L@Z#;A__],B>I(B<=,B>;H:.#__XL]
M$G\``.@=X?__N@$```!(C364(```2(G'Z"GA__^+/?-^``!)B<3H^^#__TR)
MYDB-%8D@``!(B<?H*>#__XL]TWX``.C>X/__2(GN2(T]_!X``,:`L0`````Q
MP.BFY?__2(D%%X\``$F)Q$B%P'0_OL`!``!,B>?H^M[__XU0`8/Z`78)@_@1
M#X6T````2(M$)`AD2"L$)2@````/A;T```!(@\0074%<05W##Q\`2(L]T8X`
M`.@<]O__2(D%O8X``$F)Q$B%P'6F2(T]EB```#'`Z'_@__\/'X``````@'@!
M``^$2/[__^D\_O__9@\?A```````2(L%B8X``$R+*$F+1"003(L@Z!G@__],
MB>Y,B>?HON?__^GA_O__9@\?A```````BSWJ?0``Z/7?__],B>9(B<?H2N#_
M_^E3_O__B<%(BP4\C@``3(GB2(T].B```$B+,#'`Z/C?___HL][__P\?`$%4
M28G\55-(@^P09$B+!"4H````2(E$)`@QP.@@[O__#[802(G%A-)T&&8/'T0`
M`$B#P`&`^B\/MA!(#T3HA-)U[HL%6'T``$V%Y`^5PX/X_W1MA<`/E<`APX3;
M=2)(BT0D"&1(*P0E*`````^%CP```$B#Q!!;74%<PP\?1```08`\)`!TU[H$
M````2(TU:AX``$B)[^AEW?__A<!UOTB+1"0(9$@K!"4H````=5)(@\003(GG
M6UU!7.FQY/__D#'`2(UT)`1(C3UQ'0``Z,WC__](A<!T"P^V`(3`=`0\,'4/
MQP6S?````````.EL____QP6D?````0```.E9____Z*K=__]F+@\?A```````
M05=(B?Y,C4\X059!54%455-(@>R8`@``9$B+!"4H````2(F$)(@"```QP$B)
MXDR-E"2`````28G0#Q^``````$&+`4F+.4F#P!!)@\$(#\B)P$B)^4F)0/!(
MB?A(P>D@2,'H*$C![S@E`/\``$@)^$B)STC!X0A(P><8@>$``/\`B?]("?A(
M"<A)B4#X33G0=:Y(C;H``@``#Q^``````$B+0FA(,T)`2(/""$@S0@A(,T+X
M2(T,`$C!Z!]("<B#X/](B4)X2#GZ==5,BPY,BUX02(M^($B+7AA,B<A,B<I(
MBVX(2(M,)`A(P>H;2,'@!4@)T`,$)$B-C`N9>8):C90XF7F"6DR)V$@QV$@A
MZ$@QV(T\`DB)ZDB)Z$C!Z`)(P>(>28GZ2`G"3(G82<'J&T&)T$PQP$PAR$PQ
MV$@!R$B)^4C!X05,"=%,BU0D$$2-)`A,B<A,B<E(P>D"2,'@'D^-E!.9>8):
M38GE2`G(2<'M&T@QPHG!2"'Z3#'"3`'238GB2<'B!4T)ZDR+;"0800'22(GZ
M2,'O`DC!XAY%B=)/C80HF7F"6D@)^DV)U4@QT(G73"'@2<'M&T@QR$P!P$V)
MT$G!X`5-">A,BVPD($$!P$R)X$G![`)(P>`>18G`2HV,*9EY@EI,">!-B<5(
M,<))P>T;08G$3"'22#'Z2`'*3(G!2,'A!4P)Z4R+;"0H`=%,B=))P>H"2,'B
M'HG)2HV\+YEY@EI,"=))B<U(,=!)P>T;08G23"'`3#'@2`'X2(G/2,'G!4P)
M[TR+;"0P`<=,B<!)P>@"2,'@'HG_3XVD+)EY@EI,"<!)B?U(,<))P>T;08G`
M2"'*3#'23`'B28G\2<'D!4T)[$R+;"0X00'42(G*2,'I`DC!XAY%B>1/C90J
MF7F"6D@)RDV)Y4@QT$G![1N)T4@A^$PQP$P!T$V)XDG!X@5-">I,BVPD0$$!
MPDB)^$C![P)(P>`>18G23XV$*)EY@EI("?A-B=5(,<))P>T;B<=,(>)(,<I,
M`<)-B=!)P>`%30GH3(ML)$A!`=!,B>))P>P"2,'B'D6)P$J-C"F9>8):3`GB
M38G%2#'02<'M&T&)U$PAT$@Q^$@!R$R)P4C!X05,">E,BVPD4`'!3(G02<'J
M`DC!X!Z)R4J-O"^9>8):3`G028G-2#'"2<'M&T&)PDPAPDPQXD@!^DB)STC!
MYP5,">],BVPD6`'73(G"2<'H`DC!XAZ)_T^-I"R9>8):3`G"28G]2#'02<'M
M&T&)T$@AR$PQT$P!X$F)_$G!Y`5-">Q,BVPD8$$!Q$B)R$C!X!Y(P>D"18GD
M3XV4*IEY@EI("<A-B>5(,<))P>T;B<%((?I,,<),`=)-B>))P>(%30GJ3(ML
M)&A!`=)(B?I(P>\"2,'B'D6)TD^-A"B9>8):2`GZ38G52#'02<'M&XG73"'@
M2#'(3`'`38G02<'@!4T)Z$R+;"1P00'`3(G@2<'L`DC!X!Y%B<!*C8PIF7F"
M6DP)X$V)Q4@QPDG![1M!B<1,(=)(,?I(`<I,B<%(P>$%3`GI3(ML)'@!T4R)
MTDC!XAY)P>H"B<E*C;POF7F"6DP)TDF)S4@QT$G![1M!B=),(<!,,>!(`?A(
MB<](P><%3`GO3(NL)(`````!QTR)P$G!Z`)(P>`>B?]/C:0LF7F"6DP)P$F)
M_4@QPDG![1M!B<!((<I,,=),`>))B?Q)P>0%30GL1HTL(DB)RDC!Z0),BZ0D
MB````$C!XAY("<I/C90BF7F"6DV)[$@QT$G![!N)T4@A^$PQP$P!T$V)ZDG!
MX@5-">),BZ0DD````$$!PDB)^$C!X!Y(P>\"18G23XV$()EY@EI("?A-B=1(
M,<))P>P;B<=,(>I(,<I,`<)-B=!)P>`%30G@18G`3`'"38GH2<'M`DG!X!Y!
MB=1-">A,BZPDF````$PQP$PAT$J-C"F9>8):38GE2#'X2<'M&T@!R$R)X4C!
MX05,">F)R4@!R$R)T4G!Z@)(P>$>08G%3`G138G"18G`23'*1#'23(N4)*``
M``!*C;P7H>O9;DV)ZD@!UTR)ZDG!ZAM(P>(%3`G2B=)(`==,B>)(P>(>2<'L
M`D&)^DP#A"2H````3`GB28G,B<E(`XPDL````$DQU$0QX$V-I`"AZ]EN3(G0
M38G02<'H&TC!X`5,"<")P$D!Q$R)Z$G![0)(P>`>18G@3`GH28G5B=)(`Y0D
MN````$DQQ40Q[TR-K#FAZ]EN3(G!3(G'2,'O&TC!X05("?F)R4D!S4R)T4G!
MZ@)(P>$>1(GO3`G128G"B<!),<I%,>).C:02H>O9;DB)^DF)^DG!ZAM(P>(%
M3`G2B=))`=1,B<))P>@"2,'B'D6)XDP)PDF)R$@#A"3`````B<E),=!(`XPD
MR````$4QZ$Z-K`"AZ]EN3(G038G02<'H&TC!X`5,"<")P$D!Q4B)^$C![P)(
MP>`>18GH2`GX2(G7B=)(`Y0DT````$@QQT0QYTR-I#FAZ]EN3(G!3(G'2,'O
M&TC!X05("?F)R4D!S$R)T4G!Z@)(P>$>1(GG3`G128G"B<!(`X0DV````$DQ
MRD4QZDZ-K!*AZ]EN2(GZ28GZ2<'J&TC!X@5,"=*)TDD!U4R)PDG!Z`)(P>(>
M18GJ3`G"28G(B<E),=!(`XPDX````$4QX$Z-I`"AZ]EN3(G038G02<'H&TC!
MX`5,"<")P$D!Q$B)^$C![P)(P>`>18G@2`GX2(G7B=)(`Y0DZ````$@QQT0Q
M[TR-K#FAZ]EN3(G!3(G'2,'O&TC!X05("?F)R4D!S4R)T4G!Z@)(P>$>1(GO
M3`G128G"B<!(`X0D\````$DQRD4QXDZ-I!*AZ]EN2(GZ28GZ2<'J&TC!X@5,
M"=*)TDD!U$R)PDG!Z`)(P>(>18GB3`G"28G(B<E),=!%,>A.C:P`H>O9;DR)
MT$V)T$C!X`5)P>@;2`.,)/@```!,"<")P$D!Q4B)^$C![P)(P>`>18GH2`GX
M2(G7B=)(`Y0D``$``$@QQT0QYTR-I#FAZ]EN3(G!3(G'2,'O&TC!X05("?F)
MR4D!S$R)T4G!Z@)(P>$>1(GG3`G128G"B<!(`X0D"`$``$DQRD4QZDZ-K!*A
MZ]EN2(GZ28GZ2<'J&TC!X@5,"=*)TDD!U4R)PDG!Z`)(P>(>18GJ3`G"28G(
MB<E),=!%,>!.C:0`H>O9;DR)T$V)T$G!Z!M(P>`%3`G`2`.,)!`!``")P$D!
MQ$B)^$C![P)(P>`>18G@2`GX2(G7B=)(`Y0D&`$``$@QQT0Q[TR-K#FAZ]EN
M3(G!3(G'2,'O&TC!X05("?F)R4D!S4R)T4G!Z@)(P>$>1(GO3`G128G"B<!(
M`X0D(`$``$DQRD4QXDZ-I!*AZ]EN2(GZ28GZ2<'J&TC!X@5,"=*)TDD!U$R)
MPDG!Z`)(P>(>18GB3`G"28G(B<E),=!%,>A.C:P`H>O9;DR)T$V)T$G!Z!M(
MP>`%3`G`B<!)`<5(B?A(P>`>2,'O`D6)Z$@#C"0H`0``2`GX2(G7B=)(`Y0D
M,`$``$@QQT0QYTV)Q$B-C#FAZ]EN3(G'2<'L&TC!YP5,">=-B=1)P>H"2<'D
M'HG_30G428G"2`'YB<!-,>*)ST@#A"0X`0``13'J28G]3HV4$J'KV6Y(B?I)
MP>T;2,'B!4P)ZD$!TDR)PDG!Z`)(P>(>18G23`G"38G@18GD23'028G608G5
M1#'!38G02(V,"*'KV6Y,B=!)P>@;2,'@!4P)P$2-!`%(B?E(P>\"N-R\&X](
MP>$>2`GY20G.B<]((?I-(=9)"=9(BY0D0`$``$@!PDP!XDV)Q$P!\DV)QDG!
MY`5)P>X;30GT00'43(G22<'J`DC!XAY%B>1,"=)("=%)B=9!B=))(?Y,(<%,
M"?%,B[0D2`$``$D!QDT!]4V)YDP!Z4V)Y4G![AM)P>4%30GU28G600'-3(G!
M2<'H`DC!X1Y%B>U,"<%!B<A)"<Y-(>9,(<),"?),B[0D4`$``$D!QDP!]TV)
M[D@!^DR)[TG![AM(P><%3`GW`==,B>))P>P"2,'B'HG_3`GB2`G128G608G4
M32'&3"'I3`GQ3(NT)%@!``!)`<9-`?))B?Y,`=%)B?I)P>X;2<'B!4T)\DF)
MUD$!RDR)Z4G![0)(P>$>18G23`GI08G-20G.22'^3"'J3`GR3(NT)&`!``!)
M`<9-`?!-B=9,`<)-B=!)P>`%2<'N&TT)\$$!T$B)^DC![P)(P>(>18G`2`GZ
M2`G128G6B==-(>Y,(=%,"?%,B[0D:`$``$D!QDT!]$V)QDP!X4V)Q$G![AM)
MP>0%30GT28G600',3(G12<'J`DC!X1Y%B>1,"=%!B<I)"<Y-(<9,(=),"?),
MB[0D<`$``$D!QDT!]4V)YDP!ZDV)Y4G![AM)P>4%30GU00'53(G"2,'B'DG!
MZ`)%B>U,"<)("=%)B=9!B=!-(=9,(>%,"?%,B[0D>`$``$D!QDP!]TV)[D@!
M^4R)[TG![AM(P><%3`GW28G6`<],B>%)P>P"2,'A'HG_3`GA08G,20G.32'N
M3"'B3`GR3(NT)(`!``!)`<9-`?))B?Y,`=))B?I)P>X;2<'B!4T)\D$!TDR)
MZDG![0)(P>(>18G23`GJ2`G128G608G52"'Y32'F3`GQ3(NT)(@!``!)`<9-
M`?!-B=9,`<%-B=!)P>X;2<'@!4T)\$F)UD$!R$B)^4C![P)(P>$>18G`2`GY
MB<])"<Y-(=9((?I,"?),B[0DD`$``$D!QDT!]$V)QDP!XDV)Q$G![AM)P>0%
M30GT00'43(G22<'J`DC!XAY%B>1,"=)("=%)B=9!B=))(?Y,(<%,"?%,B[0D
MF`$``$D!QDT!]4V)YDP!Z4V)Y4G![AM)P>4%30GU28G600'-3(G!2<'H`DC!
MX1Y%B>U,"<%!B<A)"<Y-(>9,(<),"?),B[0DH`$``$D!QDP!]TV)[D@!^DR)
M[TG![AM(P><%3`GW`==,B>))P>P"2,'B'HG_3`GB2`G128G608G432'&3"'I
M3`GQ3(NT)*@!``!)`<9-`?))B?Y,`=%)B?I)P>X;2<'B!4T)\DF)UD$!RDR)
MZ4G![0)(P>$>18G23`GI08G-20G.22'^3"'J3`GR3(NT)+`!``!)`<9-`?!-
MB=9,`<)-B=!)P>X;2<'@!4T)\$$!T$B)^DC![P)(P>(>18G`2`GZ2`G128G6
MB==-(>Y,(=%,"?%,B[0DN`$``$D!QDT!]$V)QDP!X4V)Q$G![AM)P>0%30GT
M28G600',3(G12<'J`DC!X1Y%B>1,"=%)"<Y!B<I-(<9,(=),"?),B[0DP`$`
M`$D!QDT!]4V)YDP!ZDV)Y4G![AM)P>4%30GU00'53(G"2<'H`DC!XAY%B>U,
M"<)("=%)B=!!B==-(=!,(>%,"<%,BX0DR`$``$D!P$P!QTV)Z$@!^4R)[TG!
MZ!M(P><%3`G'1(T$.4R)YTG![`)(B=%(P><>3`GG08G\2`GY3"'I3"'B2`G*
M2(N,)-`!``!(`<%,`=%-B<)(`X0DV`$``$@!RDR)P4G!ZAM(P>$%3`G1B<E(
M`<I,B>E)P>T"2,'A'D&)TDP)Z4@)STF)S4&)SDPAQTTAY4D)_4J-/#A,B=!,
MB[PD^`$``$P![TV)U4C!X`5)P>T;3`GHB<!(`<=,B<!)P>@"2,'@'D&)_4D)
MP+C6P6+*3#'!,=%(BY0DX`$``$@!PDP!XDV)[$@!RDR)Z4G![!M(P>$%3`GA
M38G4B<E)P>0>2`'*2<'J`DD!QTT)XDV)Q(G118G`33'41#'G3(ND).@!``!)
M`<1-`?1)B<Y,`>=)B<Q)P>X;2<'D!4T)]$V)[DG![0))P>8>18GD30GU3(NT
M)/`!``!,`>=!B?Q)`<9-`?!-B=9-,>Y$,?)-B>9)`=!,B>))P>X;2,'B!4P)
M\HG220'02(G*2,'I`DC!XAY%B<9("<I$B=%-B>I),=),`?E,B[PD``(``$0Q
MUTV)\D@!STR)\4C!X05)P>H;20''3`G1B<E(`<],B>%)P>P"2,'A'D&)^DD)
MS$2)Z4F)U8G233'E3`'Y3(N\)!`"``!%,>A-B=5)`<A,B=%)P>T;20''2,'A
M!4P)Z8G)20'(3(GQ2<'N`DC!X1Y%B<5,"?%,B[0D"`(``$D!QDP!\DV)YDDQ
MSD0Q]TV)[D@!UTR)ZDG![AM(P>(%3`GRB=)(`==,B=))P>H"2,'B'D&)_DD)
MTD2)XDF)S(G)3`'Z33'43(N\)"`"``!%,>!-B?1)`=!,B?))P>P;20''2,'B
M!4P)XHG220'03(GJ2<'M`DC!XAY%B<1,">I,BZPD&`(``$D!Q4P!Z4V)U4DQ
MU40Q[TV)Y4@!STR)X4G![1M(P>$%3`GIB<E(`<],B?%)P>X"2,'A'D&)_4D)
MSD2)T4F)THG233'R3`'Y3(N\)#`"``!%,=!-B>I)`<A,B>E)P>H;2,'A!4P)
MT8G)20'(3(GA2,'A'DG![`)%B<))`<=,">%,BZ0D*`(``$D!Q$P!XDV)]$DQ
MS$0QYTV)U$@!UTR)TDG![!M(P>(%3`GBB=)(`==,B>I)P>T"2,'B'D&)_$D)
MU42)\DF)SHG)33'N3`'Z3(N\)$`"``!%,?!-B>9)`=!,B>))P>X;2,'B!4P)
M\HG220'03(G22<'J`DC!XAY%B<9,"=),BY0D.`(``$D!PDP!T4V)ZDDQTD0Q
MUTV)\D@!STR)\4C!X05)P>H;20''3`G1B<E(`<],B>%)P>P"2,'A'D&)^DD)
MS$2)Z4F)U8G233'E3`'Y3(N\)&`"``!%,>A-B=5)`<A,B=%)P>T;2,'A!4P)
MZ8G)20'(3(GQ2<'N`DC!X1Y%B<5,"?%,B[0D2`(``$D!QDP!\DV)YD6)Y$DQ
MSD0Q]TV)[D@!UTR)ZDG![AM(P>(%3`GRB=)(`==,B=))P>H"2,'B'D&)_DD)
MTDB+E"10`@``2`'"20'42(G*B<E,,=))`<=$,<)-B?!)`=1,B?))P>@;2,'B
M!4P)PHG220'43(GJ2<'M`DC!XAY%B>!,">I,BZPD6`(``$D!Q4P!Z4V)U4DQ
MU40Q[TV)Q4@!STR)P4G![1M(P>$%3`GIB<E(`<],B?%)P>X"2,'A'D&)_4D)
MSD2)T4F)THG233'R3`'Y3(N\)'`"``!%,>)-B>Q,`=%-B>I)P>P;2<'B!4T)
MXDV)Q$6)TDG!Y!Y,`=%)P>@"20''30G@3(ND)&@"``!!B<I)`<1(`X0D>`(`
M`$P!XDV)]$P!R$TQQ$0QYTV)U$@!UTR)TDG![!M(P>(%3`GB38GL2<'M`DG!
MY!Z)TDT)Y46)]$V)QD@!UTTQ[HGZ30'\18G`1#'Q28G63`'`38GH3`'A28G4
M2<'N&TG!Y`5-"?1$`>%-B=1)P>H"2<'D'HG)30GB33'01#''28G(2`'X2(G/
M2,'G!4G!Z!L!Z4$!VDP)QT0#;B!(B4X(`?A,B5882(D&2(G02,'J`DC!X!Y,
MB6X@2`G01`'82(E&$$B+A"2(`@``9$@K!"4H````=1)(@<28`@``6UU!7$%=
M05Y!7\/H<,?__TB#[`B_@````.B"R/__NHFKS>^Y_MRZF+[PX=+#2,<``2-%
M9TB)4`A(B4@02,=`&'94,A!(B7`@2,=`*`````!(QT`P`````,=`>`````!(
M@\0(PV9F+@\?A```````D$%72&/"059)B<9!54%428G\54B-;SA32(GS2(/L
M"$B+=RA(BU<PC0S&2#GQ2(E/*$B#T@!(P>@=2`'02(E',$AC1WB%P`^%[0``
M`$&#_C\/CBL!``!!@^Y`18GW0<'O!D6-;P%)P>4&20'=#Q]$``#S#V\#3(GG
M2(/#0`\110#S#V]+T`\131#S#V]3X`\152#S#V];\`\173#HT>C__TPYZW7,
M0<'G!D4I_DECQDB#^`AR7$F+50!(C4T(2(/A^$F)5"0X28M4!?A(B50%^$@I
MS4@!Z$DI[4B#X/A(@_@(<AA(@^#X,=))BW05`$B)-!%(@\((2#G"<NY%B70D
M>$B#Q`A;74%<05U!7D%?PV:0J`1U=$B%P'3A00^V50!!B%0D.*@"=--!#[=4
M!?YFB50%_NO&#Q]``$&]0````$B-?`4`2(G>02G%13GU10]/[DUC_4R)^NBE
MQO__08M$)'A$`>A!B40D>(/X0'623(GG12GN3`'[Z/7G___IR_[__TF)W>DC
M____08M5`$&)5"0X08M4!?R)5`7\Z5O___^0059,C78X055!5%5(B?532(M&
M*$B)^T2+9BA$BVXP2,'H`X/@/T$/S$$/S8U(`4B8QD0&.(!(8\%,`?"#^3@/
MCA0!``"^0````"G.=`\QTHG1@\(!Q@0(`#GR<O-(B>_H;.?__V8/[\`/$44X
M2<=&,`````!!#Q%&$$$/$48@1(EM<$B)[T2)973H0N?__TB+10!(B>](P>@8
MB`-(BT4`2,'H$(A#`4B+10"(8P)(BT4`B$,#2(M%"$C!Z!B(0P1(BT4(2,'H
M$(A#!4B+10B(8P9(BT4(B$,'2(M%$$C!Z!B(0PA(BT402,'H$(A#"4B+11"(
M8PI(BT40B$,+2(M%&$C!Z!B(0PQ(BT482,'H$(A##4B+11B(8PY(BT48B$,/
M2(M%($C!Z!B(0Q!(BT4@2,'H$(A#$4B+12"(8Q)(BT4@B$,36UU!7$%=05[I
M/\/__P\?@`````"Z.````#'_*<J#^@AR2HG12,<``````$C'1`CX`````$B-
M2`A(@^'X2"G(`<*#XOB#^@@/@NW^__^#XO@QP(G&@\`(2(D\,3G0<O/IUO[_
M_P\?A```````]L($=2.%T@^$P?[__\8``/;"`@^$M?[__S')9HE,$/[IJ?[_
M_P\?`,<``````,=$$/P`````Z9/^__\/'T0``$%73(T]5U(``$%628G6055)
MB?5!5$&)_%5(C2U`4@``4TPI_4B#[`CH,\+__TC!_0-T&S';#Q\`3(GR3(GN
M1(GG0?\4WTB#PP%(.=UUZDB#Q`A;74%<05U!7D%?PP\?`,-F+@\?A```````
M#Q]$``!(BPWQ80``Z93#__\/'T``\P\>^DB+!=51``!(@_C_="]52(GE4TB-
M'<-1``!(@^P(#Q^``````/_02(M#^$B#ZPA(@_C_=?!(BUWXR<-FD,,```!(
M@^P(Z`/(__](@\0(PP``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````0`"`"5S+R5S`"]P<F]C+W-E;&8O97AE`$1Y;F%,;V%D97(Z.F)O
M;W1?1'EN84QO861E<@!);G1E<FYA;',Z.E!!4CHZ0D]/5``O<')O8R\E:2\E
M<P`N`%!!4E]414U0`%!!4E]04D]'3D%-10`Z`"\`4$523#5,24(`4$523$Q)
M0@!015),-4]05`!015),24\`4$%27TE.251)04Q)6D5$`%!!4E]34$%73D5$
M`%!!4E]#3$5!3@!005)?1$5"54<`4$%27T-!0TA%`%!!4E]'3$]"04Q?1$5"
M54<`4$%27T=,3T)!3%]435!$25(`4$%27U1-4$1)4@!005)?1TQ/0D%,7U1%
M35``4$%27T=,3T)!3%]#3$5!3@!005)?0TQ%04X]`#$`3$1?3$E"4D%265]0
M051(`%5315(`4UE35$5-`"]T;7``5$5-4$1)4@!435``55-%4DY!344`)3`R
M>``E<R5S)7,E<P!P87(M`'!A<FP`+G!A<@`E<R5S8V%C:&4M)7,E<P`E<R5S
M=&5M<"TE=25S`"5S)7-T96UP+25U+25U)7,`&`!P97)L`#``4$%2.CI086-K
M97(Z.E9%4E-)3TX`,2XP-30`+64`+2T``````"5S.B!C<F5A=&EO;B!O9B!P
M<FEV871E('-U8F1I<F5C=&]R>2`E<R!F86EL960@*&5R<FYO/25I*0H`````
M```E<SH@<')I=F%T92!S=6)D:7)E8W1O<GD@)7,@:7,@=6YS869E("AP;&5A
M<V4@<F5M;W9E(&ET(&%N9"!R971R>2!Y;W5R(&]P97)A=&EO;BD*````````
M56YA8FQE('1O(&-R96%T92!C86-H92!D:7)E8W1O<GD``````````"5S.B!C
M<F5A=&EO;B!O9B!P<FEV871E(&-A8VAE('-U8F1I<F5C=&]R>2`E<R!F86EL
M960@*&5R<FYO/25I*0H``````````&5V86P@)V5X96,@+W5S<B]B:6XO<&5R
M;"`@+5,@)#`@)'LQ*R(D0")])PII9B`P.R`C(&YO="!R=6YN:6YG('5N9&5R
M('-O;64@<VAE;&P*<&%C:V%G92!?7W!A<E]P;#L*;7D@*"1005)?34%'24,L
M("1P87)?=&5M<"P@)'!R;V=N86UE+"!`=&UP9FEL92P@)4UO9'5L94-A8VAE
M*3L*14Y$('L@:68@*"1%3E9[4$%27T-,14%.?2D@>PIR97%U:7)E($9I;&4Z
M.E1E;7`["G)E<75I<F4@1FEL93HZ0F%S96YA;64["G)E<75I<F4@1FEL93HZ
M4W!E8SL*;7D@)'1O<&1I<B`]($9I;&4Z.D)A<V5N86UE.CID:7)N86UE*"1P
M87)?=&5M<"D["F]U=',H<7%;4F5M;W9I;F<@9FEL97,@:6X@(B1P87)?=&5M
M<")=*3L*1FEL93HZ1FEN9#HZ9FEN9&1E<'1H*'-U8B![("@@+60@*2`_(')M
M9&ER(#H@=6YL:6YK('TL("1P87)?=&5M<"D["G)M9&ER("1P87)?=&5M<#L*
M:68@*"UD("1P87)?=&5M<"`F)B`D7D\@;F4@)TU35VEN,S(G*2!["FUY("1T
M;7`@/2!N97<@1FEL93HZ5&5M<"@*5$5-4$Q!5$4@/3X@)W1M<%A86%A8)RP*
M1$E2(#T^($9I;&4Z.D)A<V5N86UE.CID:7)N86UE*"1T;W!D:7(I+`I3549&
M25@@/3X@)RYC;60G+`I53DQ)3DL@/3X@,"P**3L*;7D@)&9I;&5N86UE(#T@
M)'1M<"T^9FEL96YA;64["G!R:6YT("1T;7`@/#PB+BXN(CL*>#TQ.R!W:&EL
M92!;(%PD>"`M;'0@,3`@73L@9&\*<FT@+7)F("<D<&%R7W1E;7`G"FEF(%L@
M7"$@+60@)R1P87)?=&5M<"<@73L@=&AE;@IB<F5A:PIF:0IS;&5E<"`Q"G@]
M8&5X<'(@7"1X("L@,6`*9&]N90IR;2`G)&9I;&5N86UE)PHN+BX*8VQO<V4@
M)'1M<#L*8VAM;V0@,#<P,"P@)&9I;&5N86UE.PIM>2`D8VUD(#T@(B1F:6QE
M;F%M92`^+V1E=B]N=6QL(#(^)C$@)B(["G-Y<W1E;2@D8VUD*3L*;W5T<RAQ
M<5M3<&%W;F5D(&)A8VMG<F]U;F0@<')O8V5S<R!T;R!P97)F;W)M(&-L96%N
M=7`Z("1F:6QE;F%M95TI.PI]"GT@?0I"14=)3B!["B1005)?34%'24,@/2`B
M7&Y005(N<&U<;B(["DEN=&5R;F%L<SHZ4$%2.CI"3T]4*"D@:68@9&5F:6YE
M9"`F26YT97)N86QS.CI005(Z.D)/3U0["F5V86P@>PI?<&%R7VEN:71?96YV
M*"D["FUY("1Q=6EE="`]("$D14Y6>U!!4E]$14)51WT["FUY("5S>7,@/2`H
M"G!A=&A?<V5P("`@(#T^("@D7D\@/7X@+UY-4U=I;B\@/R`G.R<@.B`G.B<I
M+`I?97AE("`@("`@("`]/B`H)%Y/(#U^("]>*#\Z35-7:6Y\3U,R?&-Y9W=I
M;BDO(#\@)RYE>&4G(#H@)R<I+`I?9&5L:6T@("`@("`]/B`H)%Y/(#U^("]>
M35-7:6Y\3U,R+R`_("=<7"<@.B`G+R<I+`HI.PI?<V5T7W!R;V=N86UE*"D[
M"F]U=',H<7%;7"1P<F]G;F%M92`]("(D<')O9VYA;64B72D["E]S971?<&%R
M7W1E;7`H*3L*;W5T<RAQ<5M<)$5.5GM005)?5$5-4'T@/2`B)$5.5GM005)?
M5$5-4'TB72D["FUY("@D<W1A<G1?<&]S+"`D9&%T85]P;W,I.PI-04=)0SH@
M>PIL;V-A;"`D4TE'>U]?5T%23E]??2`]('-U8B![?3L*=6YL97-S("AO<&5N
M(%]&2"P@)SPZ<F%W)RP@)'!R;V=N86UE*2!["F]U=',H<7%;0V%N)W0@<F5A
M9"!F<F]M(&9I;&4@(B1P<F]G;F%M92)=*3L@(",@9&]N)W0@=7-E("0A(&AE
M<F4@87,@:70@<F5Q=6ER97,@17)R;F\N<&T*;&%S="!-04=)0SL*?0IM>2`D
M8VAU;FM?<VEZ92`](#8T("H@,3`R-#L*;7D@)&)U9CL*;7D@)'-I>F4@/2`M
M<R!?1D@["FUY("1M86=I8U]P;W,@/2`D<VEZ92`M("1S:7IE("4@)&-H=6YK
M7W-I>F4[(",@3D]413H@)&UA9VEC7W!O<R!I<R!A(&UU;'1I<&QE(&]F("1C
M:'5N:U]S:7IE"G=H:6QE("@D;6%G:6-?<&]S(#X](#`I('L*<V5E:R!?1D@L
M("1M86=I8U]P;W,L(#`["G)E860@7T9(+"`D8G5F+"`D8VAU;FM?<VEZ92`K
M(&QE;F=T:"@D4$%27TU!1TE#*3L*:68@*"AM>2`D:2`](')I;F1E>"@D8G5F
M+"`D4$%27TU!1TE#*2D@/CT@,"D@>PHD;6%G:6-?<&]S("L]("1I.PIL87-T
M.PI]"B1M86=I8U]P;W,@+3T@)&-H=6YK7W-I>F4["GT*:68@*"1M86=I8U]P
M;W,@/"`P*2!["F]U=',H<7%;0V%N)W0@9FEN9"!M86=I8R!S=')I;F<@(B10
M05)?34%'24,B(&EN(&9I;&4@(B1P<F]G;F%M92)=*3L*;&%S="!-04=)0SL*
M?0IS965K(%]&2"P@)&UA9VEC7W!O<R`M(#0L(#`["G)E860@7T9(+"`D8G5F
M+"`T.PIS965K(%]&2"P@)&UA9VEC7W!O<R`M(#0@+2!U;G!A8VLH(DXB+"`D
M8G5F*2P@,#L*)&1A=&%?<&]S(#T@=&5L;"!?1D@["FUY("5R97%U:7)E7VQI
M<W0["G)E860@7T9(+"`D8G5F+"`T.R`@("`@("`@("`@("`@("`@("`@("`@
M("`@(",@<F5A9"!T:&4@9FER<W0@(D9)3$4B"G=H:6QE("@D8G5F(&5Q(")&
M24Q%(BD@>PIR96%D(%]&2"P@)&)U9BP@-#L*<F5A9"!?1D@L("1B=68L('5N
M<&%C:R@B3B(L("1B=68I.PIM>2`D9G5L;&YA;64@/2`D8G5F.PIO=71S*'%Q
M6U5N<&%C:VEN9R!&24Q%("(D9G5L;&YA;64B+BXN72D["FUY("1C<F,@/2`H
M("1F=6QL;F%M92`]?B!S?%XH6V$M9EQD77LX?2DO?'P@*2`_("0Q(#H@=6YD
M968["FUY("@D8F%S96YA;64L("1E>'0I(#T@*"1B=68@/7X@;7PH/SHN*B\I
M/R@N*BDH7"XN*BE\*3L*<F5A9"!?1D@L("1B=68L(#0["G)E860@7T9(+"`D
M8G5F+"!U;G!A8VLH(DXB+"`D8G5F*3L*:68@*&1E9FEN960H)&5X="D@86YD
M("1E>'0@(7X@+UPN*#\Z<&U\<&Q\:7A\86PI)"]I*2!["FUY("1F:6QE;F%M
M92`](%]S879E7V%S*"(D8W)C)&5X="(L("1B=68L(#`W-34I.PHD4$%2.CI(
M96%V>3HZ1G5L;$-A8VAE>R1F=6QL;F%M97T@/2`D9FEL96YA;64["B1005(Z
M.DAE879Y.CI&=6QL0V%C:&5[)&9I;&5N86UE?2`]("1F=6QL;F%M93L*?0IE
M;'-I9B`H("1F=6QL;F%M92`]?B!M?%XO/W-H;&EB+WP@86YD(&1E9FEN960@
M)$5.5GM005)?5$5-4'T@*2!["FUY("1F:6QE;F%M92`](%]S879E7V%S*"(D
M8F%S96YA;64D97AT(BP@)&)U9BP@,#<U-2D["F]U=',H(E-(3$E".B`D9FEL
M96YA;65<;B(I.PI]"F5L<V4@>PHD36]D=6QE0V%C:&5[)&9U;&QN86UE?2`]
M('L*8G5F(#T^("1B=68L"F-R8R`]/B`D8W)C+`IN86UE(#T^("1F=6QL;F%M
M92P*?3L*)')E<75I<F5?;&ES='LD9G5L;&YA;65]*RL["GT*<F5A9"!?1D@L
M("1B=68L(#0["GT*;&]C86P@0$E.0R`]("AS=6(@>PIM>2`H)'-E;&8L("1M
M;V1U;&4I(#T@0%\["G)E='5R;B!I9B!R968@)&UO9'5L92!O<B`A)&UO9'5L
M93L*;7D@)&EN9F\@/2`D36]D=6QE0V%C:&5[)&UO9'5L97T["G)E='5R;B!U
M;FQE<W,@)&EN9F\["F1E;&5T92`D<F5Q=6ER95]L:7-T>R1M;V1U;&5].PHD
M24Y#>R1M;V1U;&5](#T@(B]L;V%D97(O)&EN9F\O)&UO9'5L92(["FEF("@D
M14Y6>U!!4E]#3$5!3GT@86YD(&1E9FEN960H)DE/.CI&:6QE.CIN97<I*2![
M"FUY("1F:"`]($E/.CI&:6QE+3YN97=?=&UP9FEL92!O<B!D:64@(D-A;B=T
M(&-R96%T92!T96UP(&9I;&4Z("0A(CL*)&9H+3YB:6YM;V1E*"D["B1F:"T^
M<')I;G0H)&EN9F\M/GMB=69]*3L*)&9H+3YS965K*#`L(#`I.PIR971U<FX@
M)&9H.PI]"F5L<V4@>PIM>2`D9FEL96YA;64@/2!?<V%V95]A<R@B)&EN9F\M
M/GMC<F-]+G!M(BP@)&EN9F\M/GMB=69]*3L*)&EN9F\M/GMF:6QE?2`]("1F
M:6QE;F%M93L*;W!E;B!M>2`D9F@L("<\.G)A=R<L("1F:6QE;F%M92!O<B!D
M:64@<7%;0V%N)W0@<F5A9"`B)&9I;&5N86UE(CH@)"%=.PIR971U<FX@)&9H
M.PI]"F1I92`B0F]O='-T<F%P<&EN9R!F86EL960Z(&-A;B=T(&9I;F0@;6]D
M=6QE("1M;V1U;&4A(CL*?2P@0$E.0RD["G)E<75I<F4@6%-,;V%D97(["G)E
M<75I<F4@4$%2.CI(96%V>3L*<F5Q=6ER92!#87)P.CI(96%V>3L*<F5Q=6ER
M92!%>'!O<G1E<CHZ2&5A=GD["E!!4CHZ2&5A=GDZ.E]I;FET7V1Y;F%L;V%D
M97(H*3L*<F5Q=6ER92!)3SHZ1FEL93L*=VAI;&4@*&UY("1F:6QE;F%M92`]
M("AS;W)T(&ME>7,@)7)E<75I<F5?;&ES="E;,%TI('L*=6YL97-S("@D24Y#
M>R1F:6QE;F%M97T@;W(@)&9I;&5N86UE(#U^("]"4T1004XO*2!["FEF("@D
M9FEL96YA;64@/7X@+UPN<&UC/R0O:2D@>PIR97%U:7)E("1F:6QE;F%M93L*
M?0IE;'-E('L*9&\@)&9I;&5N86UE('5N;&5S<R`D9FEL96YA;64@/7X@+W-I
M=&5C=7-T;VUI>F5<+G!L)"\["GT*?0ID96QE=&4@)')E<75I<F5?;&ES='LD
M9FEL96YA;65].PI]"G5N;&5S<R`H)&)U9B!E<2`B4$M<,#`S7#`P-"(I('L*
M;W5T<RAQ<5M.;R!Z:7`@9F]U;F0@869T97(@1DE,12!S96-T:6]N(&EN(&9I
M;&4@(B1P<F]G;F%M92)=*3L*;&%S="!-04=)0R`["GT*)'-T87)T7W!O<R`]
M("AT96QL(%]&2"D@+2`T.R`@("`@("`@("`@("`@("`C('-T87)T(&]F('II
M<`I]"FUY($!P87)?87)G<SL*;7D@*"1O=70L("1B=6YD;&4L("1L;V=F:"P@
M)&-A8VAE7VYA;64I.PID96QE=&4@)$5.5GM005)?05!07U)%55-%?3L@(R!S
M86YI=&EZ92`H4D554T4@;6%Y(&)E(&$@<V5C=7)I='D@<')O8FQE;2D*)'%U
M:65T(#T@,"!U;FQE<W,@)$5.5GM005)?1$5"54=].PII9B`H(21S=&%R=%]P
M;W,@;W(@*"1!4D=66S!=(&5Q("<M+7!A<BUO<'1I;VYS)R`F)B!S:&EF="DI
M('L*;7D@)61I<W1?8VUD(#T@<7<H"G`@("!B;&EB7W1O7W!A<@II("`@:6YS
M=&%L;%]P87(*=2`@('5N:6YS=&%L;%]P87(*<R`@('-I9VY?<&%R"G8@("!V
M97)I9GE?<&%R"BD["FEF("A`05)'5B!A;F0@)$%21U9;,%T@97$@)RTM<F5U
M<V4G*2!["G-H:69T($!!4D=6.PHD14Y6>U!!4E]!4%!?4D554T5](#T@<VAI
M9G0@0$%21U8["GT*96QS92![(",@;F]R;6%L('!A<FP@8F5H879I;W5R"FUY
M($!A9&1?=&]?:6YC.PIW:&EL92`H0$%21U8I('L*)$%21U9;,%T@/7X@+UXM
M*%M!24U/0DQB<7!I=7-4=ETI*"XJ*2\@;W(@;&%S=#L*:68@*"0Q(&5Q("=)
M)RD@>PIP=7-H($!A9&1?=&]?:6YC+"`D,CL*?0IE;'-I9B`H)#$@97$@)TTG
M*2!["F5V86P@(G5S92`D,B(["GT*96QS:68@*"0Q(&5Q("=!)RD@>PIU;G-H
M:69T($!P87)?87)G<RP@)#(["GT*96QS:68@*"0Q(&5Q("=/)RD@>PHD;W5T
M(#T@)#(["GT*96QS:68@*"0Q(&5Q("=B)RD@>PHD8G5N9&QE(#T@)W-I=&4G
M.PI]"F5L<VEF("@D,2!E<2`G0B<I('L*)&)U;F1L92`]("=A;&PG.PI]"F5L
M<VEF("@D,2!E<2`G<2<I('L*)'%U:65T(#T@,3L*?0IE;'-I9B`H)#$@97$@
M)TPG*2!["F]P96X@)&QO9V9H+"`B/CXB+"`D,B!O<B!D:64@<7%;0V%N)W0@
M;W!E;B!L;V<@9FEL92`B)#(B.B`D(5T["GT*96QS:68@*"0Q(&5Q("=4)RD@
M>PHD8V%C:&5?;F%M92`]("0R.PI]"G-H:69T*$!!4D=6*3L*:68@*&UY("1C
M;60@/2`D9&ES=%]C;61[)#%]*2!["F1E;&5T92`D14Y6>R=005)?5$5-4"=]
M.PII;FET7VEN8R@I.PIR97%U:7)E(%!!4CHZ1&ES=#L*)GLB4$%2.CI$:7-T
M.CHD8VUD(GTH*2!U;FQE<W,@0$%21U8["B9[(E!!4CHZ1&ES=#HZ)&-M9")]
M*"1?*2!F;W(@0$%21U8["F5X:70["GT*?0IU;G-H:69T($!)3D,L($!A9&1?
M=&]?:6YC.PI]"GT*:68@*"1O=70I('L*>PIR97%U:7)E($E/.CI&:6QE.PIR
M97%U:7)E($%R8VAI=F4Z.EII<#L*<F5Q=6ER92!$:6=E<W0Z.E-(03L*?0IM
M>2`D<&%R(#T@<VAI9G0H0$%21U8I.PIM>2`D>FEP.PII9B`H9&5F:6YE9"`D
M<&%R*2!["F]P96X@;7D@)&9H+"`G/#IR87<G+"`D<&%R(&]R(&1I92!Q<5M#
M86XG="!F:6YD('!A<B!F:6QE("(D<&%R(CH@)"%=.PIB;&5S<R@D9F@L("=)
M3SHZ1FEL92<I.PHD>FEP(#T@07)C:&EV93HZ6FEP+3YN97<["B@@)'II<"T^
M<F5A9$9R;VU&:6QE2&%N9&QE*"1F:"P@)'!A<BD@/3T@07)C:&EV93HZ6FEP
M.CI!6E]/2R@I("D*;W(@9&EE('%Q6T5R<F]R(')E861I;F<@>FEP(&%R8VAI
M=F4@(B1P87(B73L*?0IM>2`E96YV(#T@9&\@>PII9B`H)'II<"!A;F0@;7D@
M)&UE=&$@/2`D>FEP+3YC;VYT96YT<R@G345402YY;6PG*2D@>PHD;65T82`]
M?B!S+RXJ7G!A<CHD+R]M<SL*)&UE=&$@/7X@<R]>7%,N*B\O;7,["B1M971A
M(#U^("]>("`H6UXZ72LI.B`H+BLI)"]M9SL*?0I].PII9B`H9&5F:6YE9"`D
M<&%R*2!["F]P96X@;7D@)'!H+"`G/#IR87<G+"`D<&%R(&]R(&1I92!Q<5M#
M86XG="!R96%D('!A<B!F:6QE("(D<&%R(CH@)"%=.PIM>2`D8G5F.PIR96%D
M("1P:"P@)&)U9BP@-#L*9&EE('%Q6R(D<&%R(B!I<R!N;W0@82!P87(@9FEL
M95T@=6YL97-S("1B=68@97$@(E!+7#`P,UPP,#0B.PIC;&]S92`D<&@["GT*
M0W)E871E4&%T:"@D;W5T*2`["FUY("1F:"`]($E/.CI&:6QE+3YN97<H"B1O
M=70L"DE/.CI&:6QE.CI/7T-214%4*"D@?"!)3SHZ1FEL93HZ3U]74D].3%DH
M*2!\($E/.CI&:6QE.CI/7U1254Y#*"DL"C`W-S<L"BD@;W(@9&EE('%Q6T-A
M;B=T(&-R96%T92!F:6QE("(D;W5T(CH@)"%=.PHD9F@M/F)I;FUO9&4H*3L*
M<V5E:R!?1D@L(#`L(#`["FUY("1L;V%D97(["FEF("AD969I;F5D("1D871A
M7W!O<RD@>PIR96%D(%]&2"P@)&QO861E<BP@)&1A=&%?<&]S.PI](&5L<V4@
M>PIL;V-A;"`D+R`]('5N9&5F.PHD;&]A9&5R(#T@/%]&2#X["GT*:68@*"$D
M14Y6>U!!4E]615)"051)37T@86YD("1L;V%D97(@/7X@+UXH/SHC(7Q<0')E
M;2DO*2!["G)E<75I<F4@4$%2.CI&:6QT97(Z.E!O9%-T<FEP.PI005(Z.D9I
M;'1E<CHZ4&]D4W1R:7`M/F%P<&QY*%PD;&]A9&5R+"`D,"D["GT*9F]R96%C
M:"!M>2`D:V5Y("AS;W)T(&ME>7,@)65N=BD@>PIM>2`D=F%L(#T@)&5N=GLD
M:V5Y?2!O<B!N97AT.PHD=F%L(#T@979A;"`D=F%L(&EF("1V86P@/7X@+UY;
M)R)=+SL*;7D@)&UA9VEC(#T@(E]?14Y67U!!4E\B("X@=6,H)&ME>2D@+B`B
M7U\B.PIM>2`D<V5T(#T@(E!!4E\B("X@=6,H)&ME>2D@+B`B/21V86PB.PHD
M;&]A9&5R(#U^('-[)&UA9VEC*"`K*7U["B1M86=I8R`N("1S970@+B`H)R`G
M('@@*&QE;F=T:"@D,2D@+2!L96YG=&@H)'-E="DI*0I]96<["GT*)&9H+3YP
M<FEN="@D;&]A9&5R*3L*:68@*"1B=6YD;&4I('L*<F5Q=6ER92!005(Z.DAE
M879Y.PI005(Z.DAE879Y.CI?:6YI=%]D>6YA;&]A9&5R*"D["FEN:71?:6YC
M*"D["G)E<75I<F5?;6]D=6QE<R@I.PIM>2!`:6YC(#T@9W)E<"![("$O0E-$
M4$%.+R!]"F=R97`@>PHH)&)U;F1L92!N92`G<VET92<I(&]R"B@D7R!N92`D
M0V]N9FEG.CI#;VYF:6=[87)C:&QI8F5X<'T@86YD"B1?(&YE("1#;VYF:6<Z
M.D-O;F9I9WMP<FEV;&EB97AP?2D["GT@0$E.0SL*<WPO*WPO?&<L('-\+R1\
M?"!F;W)E86-H($!I;F,["FUY("5F:6QE<SL*)&9I;&5S>R1??2LK(&9O<B!`
M1'EN84QO861E<CHZ9&Q?<VAA<F5D7V]B:F5C=',L('9A;'5E<R`E24Y#.PIM
M>2`D;&EB7V5X="`]("1#;VYF:6<Z.D-O;F9I9WML:6)?97AT?3L@("`@("`@
M("`C(%A86"!L:6)?97AT('9S(&1L97AT(#\*;7D@)7=R:71T96X["F9O<F5A
M8V@@;7D@)&ME>2`H<V]R="!K97ES("5F:6QE<RD@>PIM>2`H)&9I;&4L("1N
M86UE*3L*:68@*&1E9FEN960H;7D@)&9C(#T@)%!!4CHZ2&5A=GDZ.D9U;&Q#
M86-H97LD:V5Y?2DI('L**"1F:6QE+"`D;F%M92D@/2`H)&ME>2P@)&9C*3L*
M?0IE;'-E('L*9F]R96%C:"!M>2`D9&ER("A`:6YC*2!["FEF("@D:V5Y(#U^
M(&U\7EQ1)&1I<EQ%+R@N*BDD?&DI('L**"1F:6QE+"`D;F%M92D@/2`H)&ME
M>2P@)#$I.PIL87-T.PI]"FEF("@D:V5Y(#U^(&U\7B]L;V%D97(O6UXO72LO
M*"XJ*21\*2!["FEF("AM>2`D<F5F(#T@)$UO9'5L94-A8VAE>R0Q?2D@>PHH
M)&9I;&4L("1N86UE*2`]("@D<F5F+"`D,2D["FQA<W0["GT*:68@*"UF("(D
M9&ER+R0Q(BD@>PHH)&9I;&4L("1N86UE*2`]("@B)&1I<B\D,2(L("0Q*3L*
M;&%S=#L*?0I]"GT*?0IN97AT('5N;&5S<R!D969I;F5D("1N86UE.PIN97AT
M(&EF("1W<FET=&5N>R1N86UE?2LK.PIN97AT(&EF("%R968H)&9I;&4I(&%N
M9"`D9FEL92`]?B`O7"Y<421L:6)?97AT7$4D+VD["F]U=',H<W!R:6YT9BAQ
M<5M086-K:6YG($9)3$4@(B5S(BXN+ETL(')E9B`D9FEL92`_("1F:6QE+3Y[
M;F%M97T@.B`D9FEL92DI.PIM>2`D8V]N=&5N=#L*:68@*')E9B@D9FEL92DI
M('L*)&-O;G1E;G0@/2`D9FEL92T^>V)U9GT["GT*96QS92!["FQO8V%L("0O
M(#T@=6YD968["F]P96X@;7D@)&9H+"`G/#IR87<G+"`D9FEL92!O<B!D:64@
M<7%;0V%N)W0@<F5A9"`B)&9I;&4B.B`D(5T["B1C;VYT96YT(#T@/"1F:#X[
M"F-L;W-E("1F:#L*4$%2.CI&:6QT97(Z.E!O9%-T<FEP+3YA<'!L>2A<)&-O
M;G1E;G0L("(\96UB961D960^+R1N86UE(BD*:68@(21%3E9[4$%27U9%4D)!
M5$E-?2!A;F0@)&YA;64@/7X@+UPN*#\Z<&U\:7A\86PI)"]I.PI005(Z.D9I
M;'1E<CHZ4&%T8VA#;VYT96YT+3YN97<M/F%P<&QY*%PD8V]N=&5N="P@)&9I
M;&4L("1N86UE*3L*?0HD9F@M/G!R:6YT*")&24Q%(BP*<&%C:R@G3B<L(&QE
M;F=T:"@D;F%M92D@*R`Y*2P*<W!R:6YT9B@B)3`X>"\E<R(L($%R8VAI=F4Z
M.EII<#HZ8V]M<'5T94-20S,R*"1C;VYT96YT*2P@)&YA;64I+`IP86-K*"=.
M)RP@;&5N9W1H*"1C;VYT96YT*2DL"B1C;VYT96YT*3L*;W5T<RAQ<5M7<FET
M=&5N(&%S("(D;F%M92)=*3L*?0I]"B1Z:7`M/G=R:71E5&]&:6QE2&%N9&QE
M*"1F:"D@:68@)'II<#L*)&-A8VAE7VYA;64@/2!S=6)S='(@)&-A8VAE7VYA
M;64L(#`L(#0P.PII9B`H(21C86-H95]N86UE(&%N9"!M>2`D;71I;64@/2`H
M<W1A="@D;W5T*2E;.5TI('L*;7D@)&-T>"`]($1I9V5S=#HZ4TA!+3YN97<H
M,2D["F]P96X@;7D@)&9H+"`B/#IR87<B+"`D;W5T.PHD8W1X+3YA9&1F:6QE
M*"1F:"D["F-L;W-E("1F:#L*)&-A8VAE7VYA;64@/2`D8W1X+3YH97AD:6=E
M<W0["GT*)&-A8VAE7VYA;64@+CT@(EPP(B!X("@T,2`M(&QE;F=T:"`D8V%C
M:&5?;F%M92D["B1C86-H95]N86UE("X](")#04-(12(["B1F:"T^<')I;G0H
M)&-A8VAE7VYA;64I.PHD9F@M/G!R:6YT*'!A8VLH)TXG+"`D9F@M/G1E;&P@
M+2!L96YG=&@H)&QO861E<BDI*3L*)&9H+3YP<FEN="@D4$%27TU!1TE#*3L*
M)&9H+3YC;&]S93L*8VAM;V0@,#<U-2P@)&]U=#L*97AI=#L*?0I["FQA<W0@
M=6YL97-S(&1E9FEN960@)'-T87)T7W!O<SL*7V9I>%]P<F]G;F%M92@I.PIR
M97%U:7)E(%!!4CL*4$%2.CI(96%V>3HZ7VEN:71?9'EN86QO861E<B@I.PI[
M"G)E<75I<F4@1FEL93HZ1FEN9#L*<F5Q=6ER92!!<F-H:79E.CI::7`["GT*
M;7D@)&9H(#T@24\Z.D9I;&4M/FYE=SL@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@(",@07)C:&EV93HZ6FEP(&]P97)A=&5S(&]N(&%N($E/.CI(86YD
M;&4*)&9H+3YF9&]P96XH9FEL96YO*%]&2"DL("=R)RD@;W(@9&EE('%Q6V9D
M;W!E;B@I(&9A:6QE9#H@)"%=.PI!<F-H:79E.CI::7`Z.G-E=$-H=6YK4VEZ
M92@M<R!?1D@I.PIM>2`D>FEP(#T@07)C:&EV93HZ6FEP+3YN97<["B@@)'II
M<"T^<F5A9$9R;VU&:6QE2&%N9&QE*"1F:"P@)'!R;V=N86UE*2`]/2!!<F-H
M:79E.CI::7`Z.D%:7T]+*"D@*0IO<B!D:64@<7%;17)R;W(@<F5A9&EN9R!Z
M:7`@87)C:&EV92`B)'!R;V=N86UE(ET["D%R8VAI=F4Z.EII<#HZ<V5T0VAU
M;FM3:7IE*#8T("H@,3`R-"D["G!U<V@@0%!!4CHZ3&EB0V%C:&4L("1Z:7`[
M"B1005(Z.DQI8D-A8VAE>R1P<F]G;F%M97T@/2`D>FEP.PHD<75I970@/2`A
M)$5.5GM005)?1$5"54=].PII9B`H9&5F:6YE9"`D14Y6>U!!4E]414U0?2D@
M>R`C('-H;W5L9"!B92!S970@870@=&AI<R!P;VEN="$*9F]R96%C:"!M>2`D
M;65M8F5R("@@)'II<"T^;65M8F5R<R`I('L*;F5X="!I9B`D;65M8F5R+3YI
M<T1I<F5C=&]R>3L*;7D@)&UE;6)E<E]N86UE(#T@)&UE;6)E<BT^9FEL94YA
M;64["FYE>'0@=6YL97-S("1M96UB97)?;F%M92`]?B!M>PI>"B\_<VAL:6(O
M"B@_.B1#;VYF:6<Z.D-O;F9I9WMV97)S:6]N?2\I/PHH/SHD0V]N9FEG.CI#
M;VYF:6=[87)C:&YA;65]+RD_"BA;7B]=*RD*)`I]>#L*;7D@)&5X=')A8W1?
M;F%M92`]("0Q.PIM>2`D9&5S=%]N86UE(#T@1FEL93HZ4W!E8RT^8V%T9FEL
M92@D14Y6>U!!4E]414U0?2P@)&5X=')A8W1?;F%M92D["FEF("@M9B`D9&5S
M=%]N86UE("8F("US(%\@/3T@)&UE;6)E<BT^=6YC;VUP<F5S<V5D4VEZ92@I
M*2!["F]U=',H<7%;4VMI<'!I;F<@(B1M96UB97)?;F%M92(@<VEN8V4@:70@
M86QR96%D>2!E>&ES=',@870@(B1D97-T7VYA;64B72D["GT@96QS92!["F]U
M=',H<7%;17AT<F%C=&EN9R`B)&UE;6)E<E]N86UE(B!T;R`B)&1E<W1?;F%M
M92)=*3L*)&UE;6)E<BT^97AT<F%C=%1O1FEL94YA;65D*"1D97-T7VYA;64I
M.PIC:&UO9"@P-34U+"`D9&5S=%]N86UE*2!I9B`D7D\@97$@(FAP=7@B.PI]
M"GT*?0I]"G5N;&5S<R`H)%!!4CHZ3&EB0V%C:&5[)'!R;V=N86UE?2D@>PID
M:64@/#P@(BXB('5N;&5S<R!`05)'5CL*57-A9V4Z("0P(%L@+4%L:6(N<&%R
M(%T@6R`M261I<B!=(%L@+4UM;V1U;&4@72!;('-R8RYP87(@72!;('!R;V=R
M86TN<&P@70HD,"!;("U"?"UB(%T@6RU/;W5T9FEL95T@<W)C+G!A<@HN"B1%
M3E9[4$%27U!23T=.04U%?2`]("1P<F]G;F%M92`]("0P(#T@<VAI9G0H0$%2
M1U8I.PI]"G-U8B!#<F5A=&50871H('L*;7D@*"1N86UE*2`]($!?.PIR97%U
M:7)E($9I;&4Z.D)A<V5N86UE.PIM>2`H)&)A<V5N86UE+"`D<&%T:"P@)&5X
M="D@/2!&:6QE.CI"87-E;F%M93HZ9FEL97!A<G-E*"1N86UE+"`H)UPN+BHG
M*2D["G)E<75I<F4@1FEL93HZ4&%T:#L*1FEL93HZ4&%T:#HZ;6MP871H*"1P
M871H*2!U;FQE<W,H+64@)'!A=&@I.R`C(&UK<&%T:"!D:65S('=I=&@@97)R
M;W(*?0IS=6(@<F5Q=6ER95]M;V1U;&5S('L*<F5Q=6ER92!L:6(["G)E<75I
M<F4@1'EN84QO861E<CL*<F5Q=6ER92!I;G1E9V5R.PIR97%U:7)E('-T<FEC
M=#L*<F5Q=6ER92!W87)N:6YG<SL*<F5Q=6ER92!V87)S.PIR97%U:7)E($-A
M<G`["G)E<75I<F4@0V%R<#HZ2&5A=GD["G)E<75I<F4@17)R;F\["G)E<75I
M<F4@17AP;W)T97(Z.DAE879Y.PIR97%U:7)E($5X<&]R=&5R.PIR97%U:7)E
M($9C;G1L.PIR97%U:7)E($9I;&4Z.E1E;7`["G)E<75I<F4@1FEL93HZ4W!E
M8SL*<F5Q=6ER92!84TQO861E<CL*<F5Q=6ER92!#;VYF:6<["G)E<75I<F4@
M24\Z.DAA;F1L93L*<F5Q=6ER92!)3SHZ1FEL93L*<F5Q=6ER92!#;VUP<F5S
M<SHZ6FQI8CL*<F5Q=6ER92!!<F-H:79E.CI::7`["G)E<75I<F4@1&EG97-T
M.CI32$$["G)E<75I<F4@4$%2.PIR97%U:7)E(%!!4CHZ2&5A=GD["G)E<75I
M<F4@4$%2.CI$:7-T.PIR97%U:7)E(%!!4CHZ1FEL=&5R.CI0;V13=')I<#L*
M<F5Q=6ER92!005(Z.D9I;'1E<CHZ4&%T8VA#;VYT96YT.PIR97%U:7)E(&%T
M=')I8G5T97,["F5V86P@>R!R97%U:7)E($-W9"!].PIE=F%L('L@<F5Q=6ER
M92!7:6XS,B!].PIE=F%L('L@<F5Q=6ER92!38V%L87(Z.E5T:6P@?3L*979A
M;"![(')E<75I<F4@07)C:&EV93HZ56YZ:7`Z.D)U<G-T('T["F5V86P@>R!R
M97%U:7)E(%1I93HZ2&%S:#HZ3F%M961#87!T=7)E('T["F5V86P@>R!R97%U
M:7)E(%!E<FQ)3SL@<F5Q=6ER92!097)L24\Z.G-C86QA<B!].PIE=F%L('L@
M<F5Q=6ER92!U=&8X('T["GT*<W5B(%]S971?<&%R7W1E;7`@>PII9B`H9&5F
M:6YE9"`D14Y6>U!!4E]414U0?2!A;F0@)$5.5GM005)?5$5-4'T@/7X@+R@N
M*RDO*2!["B1P87)?=&5M<"`]("0Q.PIR971U<FX["GT*9F]R96%C:"!M>2`D
M<&%T:"`H"BAM87`@)$5.5GLD7WTL('%W*"!005)?5$U01$E2(%1-4$1)4B!4
M14U01$E2(%1%35`@5$U0("DI+`IQ=R@@0SI<7%1%35`@+W1M<"`N("D**2![
M"FYE>'0@=6YL97-S(&1E9FEN960@)'!A=&@@86YD("UD("1P871H(&%N9"`M
M=R`D<&%T:#L*;7D@)'5S97)N86UE.PIM>2`D<'=U:60["F5V86P@>R@D<'=U
M:60I(#T@9V5T<'=U:60H)#XI(&EF(&1E9FEN960@)#X[?3L*:68@*"!D969I
M;F5D*"97:6XS,CHZ3&]G:6Y.86UE*2`I('L*)'5S97)N86UE(#T@)E=I;C,R
M.CI,;V=I;DYA;64["GT*96QS:68@*&1E9FEN960@)'!W=6ED*2!["B1U<V5R
M;F%M92`]("1P=W5I9#L*?0IE;'-E('L*)'5S97)N86UE(#T@)$5.5GM54T52
M3D%-17T@?'P@)$5.5GM54T52?2!\?"`G4UE35$5-)SL*?0HD=7-E<FYA;64@
M/7X@<R]<5R]?+V<["FUY("1S=&UP9&ER(#T@(B1P871H)'-Y<WM?9&5L:6U]
M<&%R+2(N=6YP86-K*")(*B(L("1U<V5R;F%M92D["FUK9&ER("1S=&UP9&ER
M+"`P-S4U.PII9B`H(21%3E9[4$%27T-,14%.?2!A;F0@;7D@)&UT:6UE(#T@
M*'-T870H)'!R;V=N86UE*2E;.5TI('L*;W!E;B!M>2`D9F@L("(\.G)A=R(L
M("1P<F]G;F%M92!O<B!D:64@<7%;0V%N)W0@<F5A9"`B)'!R;V=N86UE(CH@
M)"%=.PIS965K("1F:"P@+3$X+"`R.PIM>2`D8G5F.PIR96%D("1F:"P@)&)U
M9BP@-CL*:68@*"1B=68@97$@(EPP0T%#2$4B*2!["G-E96L@)&9H+"`M-3@L
M(#(["G)E860@)&9H+"`D8G5F+"`T,3L*)&)U9B`]?B!S+UPP+R]G.PHD<W1M
M<&1I<B`N/2`B)'-Y<WM?9&5L:6U]8V%C:&4M)&)U9B(["GT*96QS92!["FUY
M("1D:6=E<W0@/2!E=F%L"GL*<F5Q=6ER92!$:6=E<W0Z.E-(03L*;7D@)&-T
M>"`]($1I9V5S=#HZ4TA!+3YN97<H,2D["F]P96X@;7D@)&9H+"`B/#IR87<B
M+"`D<')O9VYA;64@;W(@9&EE('%Q6T-A;B=T(')E860@(B1P<F]G;F%M92(Z
M("0A73L*)&-T>"T^861D9FEL92@D9F@I.PIC;&]S92@D9F@I.PHD8W1X+3YH
M97AD:6=E<W0["GT@?'P@)&UT:6UE.PHD<W1M<&1I<B`N/2`B)'-Y<WM?9&5L
M:6U]8V%C:&4M)&1I9V5S="(["GT*8VQO<V4H)&9H*3L*?0IE;'-E('L*)$5.
M5GM005)?0TQ%04Y](#T@,3L*)'-T;7!D:7(@+CT@(B1S>7-[7V1E;&EM?71E
M;7`M)"0B.PI]"B1%3E9[4$%27U1%35!](#T@)'-T;7!D:7(["FUK9&ER("1S
M=&UP9&ER+"`P-S4U.PIL87-T.PI]"B1P87)?=&5M<"`]("0Q(&EF("1%3E9[
M4$%27U1%35!](&%N9"`D14Y6>U!!4E]414U0?2`]?B`O*"XK*2\["GT*<W5B
M(%]S879E7V%S('L*;7D@*"1N86UE+"`D8V]N=&5N=',L("1M;V1E*2`]($!?
M.PIM>2`D9G5L;&YA;64@/2`B)'!A<E]T96UP+R1N86UE(CL*=6YL97-S("@M
M92`D9G5L;&YA;64I('L*;7D@)'1E;7!N86UE(#T@(B1F=6QL;F%M92XD)"([
M"F]P96X@;7D@)&9H+"`G/CIR87<G+"`D=&5M<&YA;64@;W(@9&EE('%Q6T-A
M;B=T('=R:71E("(D=&5M<&YA;64B.B`D(5T["G!R:6YT("1F:"`D8V]N=&5N
M=',["F-L;W-E("1F:#L*8VAM;V0@)&UO9&4L("1T96UP;F%M92!I9B!D969I
M;F5D("1M;V1E.PIR96YA;64H)'1E;7!N86UE+"`D9G5L;&YA;64I(&]R('5N
M;&EN:R@D=&5M<&YA;64I.PI]"G)E='5R;B`D9G5L;&YA;64["GT*<W5B(%]S
M971?<')O9VYA;64@>PII9B`H9&5F:6YE9"`D14Y6>U!!4E]04D]'3D%-17T@
M86YD("1%3E9[4$%27U!23T=.04U%?2`]?B`O*"XK*2\I('L*)'!R;V=N86UE
M(#T@)#$["GT*)'!R;V=N86UE('Q\/2`D,#L*:68@*"1%3E9[4$%27U1%35!]
M(&%N9"!I;F1E>"@D<')O9VYA;64L("1%3E9[4$%27U1%35!]*2`^/2`P*2![
M"B1P<F]G;F%M92`]('-U8G-T<B@D<')O9VYA;64L(')I;F1E>"@D<')O9VYA
M;64L("1S>7-[7V1E;&EM?2D@*R`Q*3L*?0II9B`H(21%3E9[4$%27U!23T=.
M04U%?2!O<B!I;F1E>"@D<')O9VYA;64L("1S>7-[7V1E;&EM?2D@/CT@,"D@
M>PII9B`H;W!E;B!M>2`D9F@L("<\)RP@)'!R;V=N86UE*2!["G)E='5R;B!I
M9B`M<R`D9F@["GT*:68@*"US("(D<')O9VYA;64D<WES>U]E>&5](BD@>PHD
M<')O9VYA;64@+CT@)'-Y<WM?97AE?3L*<F5T=7)N.PI]"GT*9F]R96%C:"!M
M>2`D9&ER("AS<&QI="`O7%$D<WES>W!A=&A?<V5P?5Q%+RP@)$5.5GM0051(
M?2D@>PIN97AT(&EF(&5X:7-T<R`D14Y6>U!!4E]414U0?2!A;F0@)&1I<B!E
M<2`D14Y6>U!!4E]414U0?3L*)&1I<B`]?B!S+UQ1)'-Y<WM?9&5L:6U]7$4D
M+R\["B@H)'!R;V=N86UE(#T@(B1D:7(D<WES>U]D96QI;7TD<')O9VYA;64D
M<WES>U]E>&5](BDL(&QA<W0I"FEF("US("(D9&ER)'-Y<WM?9&5L:6U])'!R
M;V=N86UE)'-Y<WM?97AE?2(["B@H)'!R;V=N86UE(#T@(B1D:7(D<WES>U]D
M96QI;7TD<')O9VYA;64B*2P@;&%S="D*:68@+7,@(B1D:7(D<WES>U]D96QI
M;7TD<')O9VYA;64B.PI]"GT*<W5B(%]F:7A?<')O9VYA;64@>PHD,"`]("1P
M<F]G;F%M92!\?#T@)$5.5GM005)?4%)/1TY!345].PII9B`H:6YD97@H)'!R
M;V=N86UE+"`D<WES>U]D96QI;7TI(#P@,"D@>PHD<')O9VYA;64@/2`B+B1S
M>7-[7V1E;&EM?21P<F]G;F%M92(["GT*;7D@)'!W9"`]("AD969I;F5D("9#
M=V0Z.F=E=&-W9"D@/R!#=V0Z.F=E=&-W9"@I"CH@*"AD969I;F5D("97:6XS
M,CHZ1V5T0W=D*2`_(%=I;C,R.CI'971#=V0H*2`Z(&!P=V1@*3L*8VAO;7`H
M)'!W9"D["B1P<F]G;F%M92`]?B!S+UXH/SU<+EPN/UQ1)'-Y<WM?9&5L:6U]
M7$4I+R1P=V0D<WES>U]D96QI;7TO.PHD14Y6>U!!4E]04D]'3D%-17T@/2`D
M<')O9VYA;64["GT*<W5B(%]P87)?:6YI=%]E;G8@>PII9B`H("1%3E9[4$%2
M7TE.251)04Q)6D5$?2LK(#T](#$@*2!["G)E='5R;CL*?2!E;'-E('L*)$5.
M5GM005)?24Y)5$E!3$E:141](#T@,CL*?0IF;W(@*'%W*"!34$%73D5$(%1%
M35`@0TQ%04X@1$5"54<@0T%#2$4@4%)/1TY!344@*2`I('L*9&5L971E("1%
M3E9[)U!!4E\G+B1??3L*?0IF;W(@*'%W+R!435!$25(@5$5-4"!#3$5!3B!$
M14)51R`O*2!["B1%3E9[)U!!4E\G+B1??2`]("1%3E9[)U!!4E]'3$]"04Q?
M)RXD7WT@:68@97AI<W1S("1%3E9[)U!!4E]'3$]"04Q?)RXD7WT["GT*;7D@
M)'!A<E]C;&5A;B`](")?7T5.5E]005)?0TQ%04Y?7R`@("`@("`@("`@("`@
M("(["FEF("@D14Y6>U!!4E]414U0?2D@>PID96QE=&4@)$5.5GM005)?0TQ%
M04Y].PI]"F5L<VEF("@A97AI<W1S("1%3E9[4$%27T=,3T)!3%]#3$5!3GTI
M('L*;7D@)'9A;'5E(#T@<W5B<W1R*"1P87)?8VQE86XL(#$R("L@;&5N9W1H
M*")#3$5!3B(I*3L*)$5.5GM005)?0TQ%04Y](#T@)#$@:68@)'9A;'5E(#U^
M("]>4$%27T-,14%./2A<4RLI+SL*?0I]"G-U8B!O=71S('L*<F5T=7)N(&EF
M("1Q=6EE=#L*:68@*"1L;V=F:"D@>PIP<FEN="`D;&]G9F@@(D!?7&XB.PI]
M"F5L<V4@>PIP<FEN="`B0%]<;B(["GT*?0IS=6(@:6YI=%]I;F,@>PIR97%U
M:7)E($-O;F9I9SL*<'5S:"!`24Y#+"!G<F5P(&1E9FEN960L(&UA<"`D0V]N
M9FEG.CI#;VYF:6=[)%]]+"!Q=R@*87)C:&QI8F5X<"!P<FEV;&EB97AP('-I
M=&5A<F-H97AP('-I=&5L:6)E>'`*=F5N9&]R87)C:&5X<"!V96YD;W)L:6)E
M>'`**3L*?0IP86-K86=E(&UA:6X["G)E<75I<F4@4$%2.PIU;G-H:69T($!)
M3D,L(%PF4$%2.CIF:6YD7W!A<CL*4$%2+3YI;7!O<G0H0'!A<E]A<F=S*3L*
M9&EE('%Q6W!A<BYP;#H@0V%N)W0@;W!E;B!P97)L('-C<FEP="`B)'!R;V=N
M86UE(CH@3F\@<W5C:"!F:6QE(&]R(&1I<F5C=&]R>5QN70IU;FQE<W,@+64@
M)'!R;V=N86UE.PID;R`D<')O9VYA;64["D-/4D4Z.F5X:70H)#$I(&EF("@D
M0"`]?B]>7U1+7T58251?7"@H7&0K*5PI+RD["F1I92`D0"!I9B`D0#L*?3L*
M)#HZ7U]%4E)/4B`]("1`(&EF("1`.PI]"D-/4D4Z.F5X:70H)#$I(&EF("@D
M.CI?7T524D]2(#U^+UY?5$M?15A)5%]<*"A<9"LI7"DO*3L*9&EE("0Z.E]?
M15)23U(@:68@)#HZ7U]%4E)/4CL*,3L*7U]%3D1?7PH```!P97)L>'-I+F,`
M``````````````````!?7T5.5E]005)?0TQ%04Y?7R`@("`@("`@("`@("`@
M(`$;`SO\````'@```,"`__](`0``0(3__W`!``!0A/__"`8``&"&__\8`0``
MH(?__X@!``!PB/__U`$``.")__\8`@``<(K__SP"``!0B___>`(``)"-___$
M`@```([__]P"```PCO__]`(``/".__\H`P```(___SP#```0D?__G`,``$"1
M__^P`P``()+__^`#``#`EO__,`0``$"7__],!```8)?__V0$``!PF/__P`0`
M`&"@__^0!0```*/__\0%```0I/__.`8``$"Z__^(!@``H+K__Z`&``!`O/__
M[`8``#"^__\P!P``D+[__W@'``"@OO__D`<````````4``````````%Z4@`!
M>!`!&PP'")`!!Q`4````'````$"%__\K```````````````4``````````%Z
M4@`!>!`!&PP'")`!```D````'````'!___^``P````X01@X82@\+=PB``#\:
M.RHS)"(`````%````$0```#(@O__"```````````````2````%P````0AO__
MS0````!"#A"/`D(.&(X#0@X@C01"#BB,!4$.,(8&00XX@P=$#D`";`H..$0.
M,$$.*$(.($(.&$(.$$(."$D+`$````"H````E(;__VP!````0@X0C@)"#AB-
M`T(.((P$00XHA@5!#C"#!D<.T`%^"@XP00XH00X@0@X80@X00@X(2PL`(```
M`.P```#`A___@P````!!#A"&`DH.L`$"<0H.$$$."$$+.````!`!```LB/__
MW0````!"#A".`D<.&(T#0@X@C`1$#BB&!5$.P"`"HPH.*$$.($(.&$(.$$(.
M"$8+2````$P!``#0B/__,0(```!"#A"/`D(.&(X#0@X@C01"#BB,!4$.,(8&
M1`XX@P='#E`#%0$*#CA!#C!!#BA"#B!"#AA"#A!"#@A%"Q0```"8`0``Q(K_
M_VD`````1`X0`F`."!0```"P`0``'(O__S``````1`X05@X(`#````#(`0``
M-(O__[\`````0@X0C`)!#AB&`T$.((,$1P[`0`*G"@X@1`X800X00@X(00L0
M````_`$``,"+__\%`````````%P````0`@``O(O__P("````0@X0CP)"#AB.
M`T(.((T$0@XHC`5$#C"&!DL..(,'1PZ`(@)D"@XX00XP00XH0@X@0@X80@X0
M0@X(1`L"KPZ((DX.D"):#H@B00Z`(@```!````!P`@``;(W__R4`````````
M+````(0"``"(C?__W`````!*#A"&`@)B"L8."$P+>0H."$<+2`K&#@A%"TL.
M",8`3````+0"```XCO__G@0```!"#A"/`D(.&(X#0@X@C01"#BB,!4$.,(8&
M00XX@P=+#H`!`S,$"@XX00XP00XH0@X@0@X80@X00@X(00L````8````!`,`
M`(B2__]T`````$0.(&T*#@A'"P``%````"`#``#LDO__'0````!$#A!8#@@`
M6````#@#``#TDO__"P$```!"#A"-`D(.&(P#2`X@A@1'#BB#!40.0`)""@XH
M1@X@00X80@X00@X(3`MD"@XH00X@00X80@X00@X(1@MA#DA)#E!C#DA!#D``
M``#,````E`,``*B3___L!P```$(.$(\"0@X8C@-)#B"-!$(.*(P%00XPA@9!
M#CB#!T<.P(,"`Z4!#LB#`F4.T(,"70[(@P)"#L"#`@)V"@XX1`XP00XH0@X@
M0@X80@X00@X(1`L#>`$.R(,"2P[0@P)>#LB#`D$.P(,"7`[(@P)$#M"#`E`.
MV(,"2P[@@P)+#L"#`@,&`0H..$0.,$$.*$(.($(.&$(.$$(."$T+`RP!#LB#
M`D0.T(,":`[(@P)!#L"#`@+X"@[(@P)!#M"#`D4+,````&0$``#(FO__G0(`
M``!"#A"-`D(.&(P#00X@A@1$#C`#U@$*#B!!#AA"#A!"#@A$"T````"8!```
M-)W__P8!````0@X0C`)$#AB&`T$.((,$1`XP`FL*#B!!#AA!#A!"#@A&"W,*
M#B!$#AA!#A!"#@A&"P``+````-P$``!`?O__!P(```!"#A",`D$.&(8#1`Y0
M`YP!"@X81`X00@X(00L`````3`````P%``#0G?__,!8```!"#A"/`DD.&(X#
M0@X@C01"#BB,!4$.,(8&00XX@P='#M`%`P@6"@XX00XP00XH0@X@0@X80@X0
M0@X(00L````4````7`4``+"S__]4`````$0.$`)/#@A(````=`4``/BS__^?
M`0```$(.$(\"10X8C@-%#B"-!$(.*(P%1`XPA@9%#CB#!T<.0`+E"@XX00XP
M00XH0@X@0@X80@X00@X(0PL`0````,`%``!,M?__ZP$```!"#A".`D8.&(T#
M0@X@C`1!#BB&!40.,(,&`S8!"@XH00X@0@X80@X00@X(3`L```````!$````
M!`8``/BV__]=`````$(.$(\"20X8C@-%#B"-!$4.*(P%1`XPA@9(#CB#!T<.
M0&H..$$.,$$.*$(.($(.&$(.$$(."``4````3`8``!"W__\!````````````
M```0````9`8```BW__\,````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````#__________P``````````__________\```````````$`
M````````Y0(````````!`````````/4"`````````0`````````%`P``````
M``P``````````"`````````-`````````&1>````````]?[_;P````"@`P``
M``````4`````````N`T````````&`````````*`$````````"@````````";
M!`````````L`````````&``````````5`````````````````````P``````
M``#PL0````````(`````````*`4````````4``````````<`````````%P``
M``````#X%`````````<`````````J!,````````(`````````%`!````````
M"0`````````8`````````!X`````````"`````````#[__]O``````$```@`
M````_O__;P`````8$P```````/___V\``````@````````#P__]O`````%02
M````````^?__;P`````"````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````(+``````````````````````````````1B````````!6
M(````````&8@````````=B````````"&(````````)8@````````IB``````
M``"V(````````,8@````````UB````````#F(````````/8@````````!B$`
M```````6(0```````"8A````````-B$```````!&(0```````%8A````````
M9B$```````!V(0```````(8A````````EB$```````"F(0```````+8A````
M````QB$```````#6(0```````.8A````````]B$````````&(@```````!8B
M````````)B(````````V(@```````$8B````````5B(```````!F(@``````
M`'8B````````AB(```````"6(@```````*8B````````MB(```````#&(@``
M`````-8B````````YB(```````#V(@````````8C````````%B,````````F
M(P```````#8C````````1B,```````!6(P```````&8C````````=B,`````
M``"&(P```````)8C````````IB,`````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````(P````````/____\`````X&(```````!'
M0T,Z("A$96)I86X@,3$N,BXP+3$V*2`Q,2XR+C```"YS:'-T<G1A8@`N:6YT
M97)P`"YN;W1E+F=N=2YP<F]P97)T>0`N;F]T92YG;G4N8G5I;&0M:60`+FYO
M=&4N04))+71A9P`N9VYU+FAA<V@`+F1Y;G-Y;0`N9'EN<W1R`"YG;G4N=F5R
M<VEO;@`N9VYU+G9E<G-I;VY?<@`N<F5L82YD>6X`+G)E;&$N<&QT`"YI;FET
M`"YP;'0N9V]T`"YT97AT`"YF:6YI`"YR;V1A=&$`+F5H7V9R86UE7VAD<@`N
M96A?9G)A;64`+F-T;W)S`"YD=&]R<P`N9'EN86UI8P`N9&%T80`N8G-S`"YC
M;VUM96YT````````````````````````````````````````````````````
M``````````````````````````````````````L````!`````@`````````8
M`P```````!@#````````'`````````````````````$`````````````````
M```3````!P````(`````````.`,````````X`P```````"``````````````
M```````(````````````````````)@````<````"`````````%@#````````
M6`,````````D````````````````````!````````````````````#D````'
M`````@````````!\`P```````'P#````````(`````````````````````0`
M``````````````````!'````]O__;P(`````````H`,```````"@`P``````
M`/P`````````!@`````````(````````````````````40````L````"````
M`````*`$````````H`0````````8"0````````<````!````"``````````8
M`````````%D````#`````@````````"X#0```````+@-````````FP0`````
M``````````````$```````````````````!A````____;P(`````````5!(`
M``````!4$@```````,(`````````!@`````````"``````````(`````````
M;@```/[__V\"`````````!@3````````&!,```````"0``````````<````"
M````"````````````````````'T````$`````@````````"H$P```````*@3
M````````4`$````````&``````````@`````````&`````````"'````!```
M`$(`````````^!0```````#X%````````"@%````````!@```!<````(````
M`````!@`````````D0````$````&```````````@`````````"`````````A
M````````````````````!````````````````````(P````!````!@``````
M```P(````````#`@````````@`,``````````````````!``````````$```
M``````"7`````0````8`````````L",```````"P(P````````@`````````
M```````````(``````````@`````````H`````$````&`````````,`C````
M````P",```````"A.@``````````````````$````````````````````*8`
M```!````!@````````!D7@```````&1>````````#@``````````````````
M``0```````````````````"L`````0````(``````````&``````````8```
M`````'`_```````````````````0````````````````````M`````$````"
M`````````'"?````````<)\```````#\````````````````````!```````
M`````````````,(````!`````@````````!PH````````'"@````````J`8`
M``````````````````@```````````````````#,`````0````,`````````
M`+``````````L````````!`````````````````````(````````````````
M````TP````$````#`````````!"P````````$+`````````0````````````
M````````"````````````````````-H````&`````P`````````@L```````
M`""P````````T`$````````'``````````@`````````$`````````";````
M`0````,`````````\+$```````#PL0```````!`"```````````````````(
M``````````@`````````XP````$````#``````````#``````````,``````
M```@````````````````````"````````````````````.D````(`````P``
M```````@P````````"#`````````@!```````````````````"``````````
M``````````#N`````0```#`````````````````````@P````````!\`````
M```````````````!``````````$``````````0````,`````````````````
M````````/\````````#W`````````````````````0``````````````````
!````
